<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'APPTITLE'                     => 'Vtiger CRM'                  ,
	'POWEREDBY'                    => 'Powered by vtiger CRM'       ,
	'LBL_READ_LICENSE'             => 'Read License'                ,
	'LBL_PRIVACY_POLICY'           => 'Privacy Policy'              ,
	'LBL_SELECT_ALL'               => 'Select All'                  ,
	'LBL_SELECT_TO_LOAD_LIST'      => 'Select to Load List'         , // TODO: Review
	'LBL_CREATING_NEW'             => 'Creating New'                ,
	'LBL_EDITING'                  => 'Editing'                     ,
	'LBL_SAVE'                     => 'Save'                        ,
	'LBL_CANCEL'                   => 'Cancel'                      ,
	'LBL_BACK'                     => 'Back'                        ,
	'LBL_IMPORT'                   => 'Import'                      ,
	'LBL_EXPORT'                   => 'Export'                      ,
	'LBL_FIND_DUPLICATES'          => 'Find duplicates'             ,
	'LBL_MORE'                     => 'More'                        ,
	'LBL_ACTIONS'                  => 'Actions'                     ,
	'LBL_ADD'                      => 'Add'                         ,
	'LBL_EDIT'                     => 'Edit'                        ,
	'LBL_DELETE'                   => 'Delete'                      ,
	'LBL_SETTINGS'                 => 'Settings'                    ,
	'LBL_ADD_COMMENT'              => 'Add Comment'                 ,
	'LBL_EDIT_FIELDS'              => 'Edit Fields'                 ,
	'LBL_EDIT_WORKFLOWS'           => 'Edit Workflows'              ,
	'LBL_EDIT_PICKLIST_VALUES'     => 'Edit Picklist Values'        ,
	'LBL_EDIT_MAILSCANNER'         => 'Convert Emails'              ,
	'LBL_RECORD_DELETE'            => 'The record you are trying to view has been deleted.',
	'LBL_RECORD_NOT_FOUND'         => 'Record you are trying to access is not found',
	'LBL_SELECT'                   => 'Select'                      ,
	'LBL_CLEAR'                    => 'Clear'                       ,
	'LBL_YES'                      => 'Yes'                         ,
	'LBL_NO'                       => 'No'                          ,
	'LBL_SHOW_COMPLETE_DETAILS'    => 'Complete Details'            , // TODO: Review
	'LBL_MASS_EDITING'             => 'Mass Editing'                ,
	'LBL_DESELECT_ALL_RECORDS'     => 'Deselect all'                ,
	'LBL_QUICK_CREATE'             => 'Quick Create'                ,
	'LBL_SEND_EMAIL'               => 'Send Email'                  ,
	'LBL_ALL_EMAILS'               => 'All email accounts'          ,
	'LBL_MUTIPLE_EMAIL_SELECT_ONE' => 'Please select one of the options below',
	'LBL_GO_TO_FULL_FORM'          => 'Go to full form'             ,
	'LBL_SEND_SMS'                 => 'Send SMS'                    ,
	'LBL_FOUND'                    => 'Found'                       ,
	'LBL_CLICK_ADD'                => 'Click to add'                ,
	'LBL_ADD_MORE_FIELDS'          => 'Add more fields'             ,
	'LBL_ADD_NOTE'                 => 'Add Note'                    ,
	'LBL_CREATE_NEW'               => 'Create New'                  ,
	'LBL_ADD_EVENT'                => 'Add Event'                   ,
	'LBL_ADD_TASK'				   => 'Add To Do'					,
	'LBL_MARKETING_AND_SALES'      => 'MARKETING & SALES'           ,
	'LBL_TOOLS_HEADER'             => 'TOOLS'                       ,
	'LBL_SUPPORT'                  => 'SUPPORT'                     ,
	'LBL_INVENTORY'                => 'INVENTORY'                   ,
	'LBL_ANALYTICS'                => 'ANALYTICS'                   ,
	'LBL_HOME'                     => 'Home'                        ,
	'LBL_LAST_VIEWED_RECORDS'      => 'Last Viewed Records'         ,
	'LBL_DASHBOARD'                => 'Dashboard'                   ,
	'LBL_USER_SETTINGS'            => 'User Settings'               ,
	'LBL_MY_PREFERENCES'           => 'My Preferences'              ,
	'LBL_SIGN_OUT'                 => 'Sign Out'                    ,
	'LBL_HELP'                     => 'Help'                        ,
	'LBL_DOCUMENTATION'            => 'Documentation'               , // TODO: Review
	'LBL_VIDEO_TUTORIAL'           => 'Video Tutorial'              , // TODO: Review
	'LBL_FEEDBACK'                 => 'Feedback'                    ,
	'LBL_CHAT_SUPPORT'			   => 'Chat Support',
	'LBL_CRM_SETTINGS'             => 'CRM Settings'                ,
	'LBL_ON_DEMAND_ADMIN'          => 'Add / Delete Users'          , // TODO: Review
	'LBL_ANNOUNCEMENT'             => 'Announcement'                ,
	'LBL_CALENDAR'                 => 'Calendar'                    ,
	'LBL_POST'                     => 'Post'                        ,
	'LBL_GUIDER'                   => 'Guider'                      , // TODO: Review
	'LBL_DISPLAY_TYPE'             => 'Display Type'                , // TODO: Review
	'LBL_DISPLAY_WIDETYPE'         => 'Wide'                        , // TODO: Review
	'LBL_DISPLAY_MEDIUMTYPE'       => 'Medium'                      , // TODO: Review
	'LBL_DISPLAY_NARROWTYPE'       => 'Narrow'                      , // TODO: Review
	'LBL_TAG_THIS_RECORD'          => 'Tag this Record'             , // TODO: Review
	'LBL_PAGE'                     => 'Page'                        , // TODO: Review
	'LBL_LISTVIEW_PAGE_JUMP'       => 'Page Jump'                   , // TODO: Review
	'LBL_USER'                     => 'User'                        , 
	'LBL_GROUP'                    => 'Group'                       , 
	'Last Modified By'             => 'Last Modified By'            , 
	'Created Time'                 => 'Created Time'                , 
	'Modified Time'                => 'Modified Time'               , 
	'Description'                  => 'Description'                 , 
	'Assigned To'                  => 'Assigned To'                 , 
	'LBL_LOADING'                  => 'Loading...'                  , 
	'LBL_LOADING_WIDGET'           => 'Loading Widget'              , 
	'LBL_LOADING_LISTVIEW_CONTENTS' => 'Loading, Please wait.'      , 
	'LBL_UPDATES'                  => 'Updates'                     , 
	'LBL_SHOW_FULL_DETAILS'        => 'Show Full Details'           , // TODO: Review
	'LBL_SUMMARY_DETAILS'          => 'Summary Details'             ,
	'LBL_ADD_NEW_COMMENT'          => 'Add New Comment'             ,
	'LBL_NO_UPDATES'               => 'No Updates'                  ,
	'LBL_ACTIVITIES'               => 'Activities'                  , // TODO: Review
	'LBL_NO_PENDING_ACTIVITIES'    => 'No pending activities'       , // TODO: Review
	'LBL_SUMMARY'                  => 'Summary'                     , // TODO: Review
	'LBL_DETAILS'                  => 'Details'                     , // TODO: Review
	'LBL_SEARCH_FOR'               => 'Search for'                  ,
	'LBL_IN'                       => 'In'                          ,
	'LBL_TYPE_SEARCH'              => 'Type to search'              ,
	'LBL_SEARCH_BUTTON'            => 'Search Button'               ,
	'LBL_ADVANCE_SEARCH'           => 'Advanced'             ,
	'LBL_LOADING_PLEASE_WAIT'      => 'Loading, Please wait.'       ,
	'LBL_USERS'                    => 'Users'                       ,
	'LBL_GROUPS'                   => 'Groups'                      ,
	'LBL_FULL_FORM'                => 'Full Form'                   ,
	'LBL_SIMPLE_FORM'              => 'Simple Form'                 ,
	'LBL_ADD_YOUR_COMMENT_HERE'    => 'Add your comment here...'    ,
	'LBL_REPLY'                    => 'Reply'                       ,
	'LBL_VIEW_THREAD'              => 'View Thread'                 ,
	'LBL_NO_COMMENTS'              => 'No Comments'                 ,
	'LBL_REPLIES'                  => 'replies'                     ,
    'LBL_REPLY_ALL'                => 'Reply all'                   ,
	'Accounts'                     => 'Organisations'               ,
	'Assets'                       => 'Assets'                      ,
	'Calendar'                     => 'Calendar'                    ,
	'Campaigns'                    => 'Campaigns'                   ,
	'Contacts'                     => 'Contacts'                    ,
	'Documents'                    => 'Documents'                   ,
	'Leads'                        => 'Leads'                       ,
	'ModComments'                  => 'Comments'                    ,
	'Potentials'                   => 'Opportunities'               ,
	'PriceBooks'                   => 'Price Books'                 ,
	'Products'                     => 'Products'                    ,
	'Project'                      => 'Projects'                    ,
	'ProjectMilestone'             => 'Project Milestones'          ,
	'ProjectTask'                  => 'Project Tasks'               ,
	'ServiceContracts'             => 'Service Contracts'           ,
	'Services'                     => 'Services'                    ,
	'Vendors'                      => 'Vendors'                     ,
	'Rss'                          => 'RSS'                         ,
	'Quotes'                       => 'Quotes'                      ,
	'PurchaseOrder'                => 'Purchase Order'              ,
	'SalesOrder'                   => 'Sales Order'                 ,
	'Invoice'                      => 'Invoice'                     ,
	'MailManager'                  => 'Mail Manager'                , // TODO: Review
	'Activities'				   => 'Activities'					,
        'Portal'                       => 'Our Sites'                   ,
        'Email Templates'              => 'Email Template'              ,
        'Recycle Bin'                  => 'Recycle Bin'                 ,

	'LBL_ADD_RECORD'               => 'Add Record'                  ,
	'LBL_RECENTLY_MODIFIED'        => 'Recently Modified'           ,
	'LBL_RECORDS_LIST'             => 'Records List'                ,
	'LBL_RECORD_SUMMARY'           => 'Module Summary'              ,
	'LBL_ACCESS_DENIED_FOR'        => 'Access Denied for'           ,
	'LBL_GO_BACK'                  => 'Go Back'                     ,
	'LBL_NO_DATA_AVAILABLE'        => 'No data available'           ,
	'LBL_GLOBAL_SEARCH'            => 'Type keyword and press enter',
	'LBL_ALL_RECORDS'              => 'All Records'                 , // TODO: Review
	'LBL_NO_RECORDS_FOUND'         => 'No records found'            , // TODO: Review
	'LBL_AND'                      => 'and'                         ,
	'LBL_OR'                       => 'or'                          ,
	'LBL_NONE'                     => '--None--'                    ,
	'LBL_APPROVE'                  => 'Approve'                     ,
	'LBL_HAS_CHANGED' => 'has changed',
	'LBL_HAS_CHANGED_TO' => 'has changed to',
	'LBL_HAS_CHANGED_FROM' => 'has changed from',
	'LBL_LESS_THAN_OR_EQUAL_TO' => 'less than or equal to',
	'LBL_GREATER_THAN_OR_EQUAL_TO' => 'greater than or equal to',
	'LBL_IS_NOT' => 'is not',
	'LBL_IS_ADDED' => 'is added',
	'LBL_IS_TODAY' => 'is today',
	'LBL_IS_TOMORROW' => 'is tomorrow',
	'LBL_IS_YESTERDAY' => 'is yesterday',
	'LBL_LESS_THAN_DAYS_LATER' => 'less than days later',
	'LBL_MORE_THAN_DAYS_LATER' => 'more than days later',
	'LBL_DENY'                     => 'Deny'                        ,
	'LBL_EQUALS'                   => 'equals'                      ,
	'LBL_NOT_EQUAL_TO'             => 'not equal to'                ,
	'LBL_STARTS_WITH'              => 'starts with'                 ,
	'LBL_ENDS_WITH'                => 'ends with'                   ,
	'LBL_CONTAINS'                 => 'contains'                    ,
	'LBL_DOES_NOT_CONTAIN'         => 'does not contains'           ,
	'LBL_LESS_THAN'                => 'less than'                   ,
	'LBL_GREATER_THAN'             => 'greater than'                ,
	'LBL_LESS_THAN_OR_EQUAL'       => 'less or equal'               ,
	'LBL_GREATER_OR_EQUAL'         => 'greater or equal'            ,
	'LBL_BEFORE'                   => 'before'                      ,
	'LBL_AFTER'                    => 'after'                       ,
	'LBL_BETWEEN'                  => 'between'                     ,
    'LBL_IS_NOT_EMPTY'             => 'is not empty'                ,
	'LBL_SEARCH'                   => 'Search'                      ,
	'LBL_SEARCH_IN'                => 'Search In'                   ,
	'LBL_ADD_CONDITION'            => 'Add Condition'               ,
	'LBL_ADD_GROUP'                => 'Add Group'                   ,
	'LBL_FILTER_CONDITIONS'        => 'Filter Conditions'           ,
	'LBL_ALL_CONDITIONS'           => 'All Conditions'              ,
	'LBL_ALL_CONDITIONS_DESC'      => 'All conditions must be met'  ,
	'LBL_ANY_CONDITIONS'           => 'Any Conditions'              ,
	'LBL_ANY_CONDITIONS_DESC'      => 'At least one of the conditions must be met',
	'LBL_SELECT_FIELD'             => 'Select Field'                ,
	'LBL_SELECT_MODULE'            => 'Select Module'               ,
	'LBL_CREATE_NEW_FILTER'        => 'Create New Filter'           ,
	'All'                          => 'All'                         ,
	'Others'                       => 'Others'                      ,
	'Pending'                      => 'Pending'                     ,
	'Public'                       => 'Public'                      ,
	'LBL_SAVE_FILTER'              => 'Save Filter'                 ,
	'LBL_SAVE_MODIFY_FILTER'       => 'Save/Modify Filter'          ,
	'LBL_SEARCH_RESULTS'           => 'Search Results'              ,
	'LBL_SAVE_AS_FILTER'           => 'Save As Filter'              ,
	'LBL_NOT_ACCESSIBLE'           => 'Not Accessible'              ,
	'LBL_ITEM_DETAILS'             => 'Item Details'                ,
	'LBL_CURRENCY'                 => 'Currency'                    ,
	'LBL_TAX_MODE'                 => 'Tax Mode'                    ,
	'LBL_INDIVIDUAL'               => 'individual'                  ,
	'LBL_TOOLS'                    => 'Tools'                       ,
	'LBL_ITEM_NAME'                => 'Item Name'                   ,
	'LBL_QTY_IN_STOCK'             => 'Qty. In Stock'               ,
	'LBL_QTY'                      => 'Qty'                         ,
	'LBL_LIST_PRICE'               => 'List Price'                  ,
	'LBL_TOTAL'                    => 'Total'                       ,
	'LBL_NET_PRICE'                => 'Net Price'                   ,
	'LBL_DISCOUNT'                 => 'Discount'                    ,
	'LBL_TOTAL_AFTER_DISCOUNT'     => 'Total After Discount'        ,
	'LBL_TAX'                      => 'Tax'                         ,
	'LBL_ADD_PRODUCT'              => 'Add Product'                 ,
	'LBL_ADD_SERVICE'              => 'Add Service'                 ,
	'LBL_ITEMS_TOTAL'              => 'Items Total'                 , // TODO: Review
	'LBL_SHIPPING_AND_HANDLING_CHARGES' => 'Shipping & Handling Charges' ,
	'LBL_PRE_TAX_TOTAL'            => 'Pre Tax Total'               , // TODO: Review
	'LBL_TAX_FOR_SHIPPING_AND_HANDLING' => 'Taxes For Shipping and Handling',
	'LBL_SET_SHIPPING_AND_HANDLING_TAXES_FOR' => 'Set S&H Taxes For'           ,
	'LBL_ADJUSTMENT'               => 'Adjustment'                  ,
	'LBL_DEDUCT'                   => 'Deduct'                      ,
	'LBL_GRAND_TOTAL'              => 'Grand Total'                 ,
	'LBL_ZERO_DISCOUNT'            => 'Zero Discount'               ,
	'LBL_OF_PRICE'                 => 'of Price'                    ,
	'LBL_DIRECT_PRICE_REDUCTION'   => 'Direct Price Reduction'      ,
	'LBL_SET_DISCOUNT_FOR'         => 'Set Discount For'            ,
	'LBL_STOCK_NOT_ENOUGH'         => 'Not enough stock'            ,
	'LBL_MAX_QTY_SELECT'           => 'Maxmimum value is'           ,
	'LBL_DRAG'                     => 'Drag'                        ,
	'LBL_TOTAL_TAX_AMOUNT'         => 'Total Tax Amount'            ,
	'LBL_DIRECT_AMOUNT_DISCOUNT'   => 'Direct Amount Discount'      ,
	'LBL_FINAL_DISCOUNT_AMOUNT'    => 'Final Discount Amount'       ,
	'LBL_MORE_CURRENCIES'          => 'more currencies'             ,
	'LBL_SET_TAX_FOR'              => 'Set Tax for'                 , // TODO: Review
	'LBL_GROUP_TAX'                => 'Group Tax'                   , // TODO: Review
	'LBL_BILLING_ADDRESS_FROM'     => 'Copy Invoice Address from'   , // TODO: Review
	'LBL_SHIPPING_ADDRESS_FROM'    => 'Copy Delivery Address from'  , // TODO: Review
	'LBL_COPY_SHIPPING_ADDRESS'    => 'Delivery Address'            , // TODO: Review
	'LBL_COPY_BILLING_ADDRESS'     => 'Invoice Address'             , // TODO: Review
	'LBL_OVERALL_DISCOUNT'			=> 'Overall Discount'			,
	'LBL_CHARGES'					=> 'Charges'					,
	'LBL_CHARGES_TOTAL'				=> 'Charges Total'				,
	'LBL_TAXES_ON_CHARGES'			=> 'Taxes On Charges'			,
	'LBL_DEDUCTED_TAXES'			=> 'Deducted Taxes'				,
	'LBL_DEDUCTED_TAXES_TOTAL'		=> 'Deducted Taxes Total'		,
	'LBL_DEFAULT'					=> 'Default'					,
	'LBL_ITEM'						=> 'Item'						,
	'LBL_CREATE'                   => 'Create'                      ,
	'LBL_GENERATE'                 => 'Generate'                    ,
	'LBL_DUPLICATE'                => 'Duplicate'                   ,
	'LBL_ADD_WIDGET'               => 'Add Widget'                  ,
	'LBL_COMMENTS'                 => 'Comments'                    ,
	'LBL_REFRESH'                  => 'Refresh'                     ,
	'LBL_CLOSE'                    => 'Close'                       ,
	'LBL_ALL'                      => 'All'                         ,
	'LBL_UPDATED'                  => 'Updated'                     ,
	'LBL_FROM'                     => 'from'                        ,
	'LBL_TO'                       => 'to'                          ,
	'LBL_ON'                       => 'on'                          ,
	'LBL_OF'                       => 'of'                          ,
	'LBL_BY'                       => 'By '                         ,
	'LBL_ADDED'                    => 'added'                       ,
	'LBL_FOR'                      => 'for'                         ,
	'LBL_CREATED'                  => 'Created'                     ,
	'LBL_DELETED'                  => 'deleted'                     ,
	'LBL_RESTORED'                 => 'restored'                    ,
	'LBL_COMMENTED'                => 'commented'                   ,
	'LBL_REMOVED'                  => 'removed'                     ,
	'LBL_REMOVE'                   => 'Remove'                      ,
	'LBL_AT'                       => 'at'                          ,
	'LBL_MINE'                     => 'Mine'                        ,
	'History'                      => 'History'                     ,
	'Upcoming Tasks'               => 'Upcoming Tasks'              ,
	'LBL_YEAR'                     => 'year'                        ,
	'LBL_YEARS'                    => 'years'                       ,
	'LBL_MONTH'                    => 'month'                       ,
	'LBL_MONTHS'                   => 'months'                      ,
	'LBL_DAY'                      => 'day'                         ,
	'LBL_DAYS'                     => 'days'                        ,
	'LBL_HOUR'                     => 'hour'                        ,
	'LBL_HOURS'                    => 'hours'                       ,
	'LBL_MINUTE'                   => 'minute'                      ,
	'LBL_MINUTES'                  => 'Minutes'                     ,
	'LBL_SECOND'                   => 'second'                      ,
	'LBL_SECONDS'                  => 'seconds'                     ,
	'LBL_JUSTNOW'                  => 'just now'                    ,
	'LBL_CUSTOM_INFORMATION'       => 'Custom Information'          ,
	'LBL_NO_RECENT_UPDATES'        => 'No recent updates'           ,
	'LBL_NO_DATA'                  => 'No Data Found'               ,
	'LBL_PERMISSION_DENIED'        => 'Permission denied'           ,
	'LBL_HANDLER_NOT_FOUND'        => 'Handler not found'           ,
	'LBL_FILTER'                   => 'Filter'                      ,
	'LBL_DUE'                      => 'due'                         ,
	'LBL_COMPLETED'                => 'completed'                   ,
	'LBL_AGO'                      => 'ago'                         ,
	'LBL_CHANGED'                  => 'changed'                     ,
	'Single_Users'                 => 'User'                        ,
	'LBL_MATCHED_THIS_CRITERIA'    => 'matched this criteria'       ,
	'LBL_NO_SCHEDULED_ACTIVITIES'  => 'No scheduled activities'     ,
	'LBL_NO_OVERDUE_ACTIVITIES'    => 'No overdue activities'       ,
	'LBL_NO_UPDATES_OR_COMMENTS'   => 'No updates or comments'      ,
	'LBL_MINI_LIST'                => 'Mini List'                   , // TODO: Review
	'Mini List'                    => 'Mini List'                   , // TODO: Review
	'LBL_RESULT_FOR_THE_TAG'       => 'Results for the tag'         , // TODO: Review
        'LBL_ALL_USERS'                => 'All Users',
        'LBL_BOTH'                     => 'Both',
        'LBL_SHOW'                     => 'Show',
	'LBL_SELECT_DATE_RANGE' => 'Select Date Range',
	'LBL_VIEW_NAME'                => 'View Name'                   ,
	'LBL_CREATE_VIEW'              => 'Creating new view'           ,
	'LBL_BASIC_DETAILS'            => 'Basic details'               ,
	'LBL_CHOOSE_COLUMNS'           => 'Choose columns and order'    ,
	'LBL_MAX_NUMBER_FILTER_COLUMNS' => 'Max 15'                      ,
	'LBL_FILTER_ON_DATE'           => 'Filter on date'              ,
	'LBL_CHOOSE_FILTER_CONDITIONS' => 'Choose filter conditions'    ,
	'LBL_SET_AS_DEFAULT'           => 'Set as Default'              ,
	'LBL_LIST_IN_METRICS'          => 'List in Metrics'             ,
	'LBL_SET_AS_PUBLIC'            => 'Set as Public'               ,
	'LBL_ADD_MORE_COLUMNS'         => 'Add more columns'            ,
	'LBL_CUSTOM'                   => 'Custom'                      ,
	'LBL_PREVIOUS_FY'              => 'Previous FY'                 ,
	'LBL_CURRENT_FY'               => 'Current FY'                  ,
	'LBL_NEXT_FY'                  => 'Next FY'                     ,
	'LBL_PREVIOUS_FQ'              => 'Previous FQ'                 ,
	'LBL_CURRENT_FQ'               => 'Current FQ'                  ,
	'LBL_NEXT_FQ'                  => 'Next FQ'                     ,
	'LBL_YESTERDAY'                => 'Yesterday'                   ,
	'LBL_TODAY'                    => 'Today'                       ,
	'LBL_TOMORROW'                 => 'Tomorrow'                    ,
	'LBL_LAST_WEEK'                => 'Last Week'                   ,
	'LBL_CURRENT_WEEK'             => 'Current Week'                ,
	'LBL_NEXT_WEEK'                => 'Next Week'                   ,
	'LBL_LAST_MONTH'               => 'Last Month'                  ,
	'LBL_CURRENT_MONTH'            => 'Current Month'               ,
	'LBL_NEXT_MONTH'               => 'Next Month'                  ,
	'LBL_LAST_7_DAYS'              => 'Last 7 Days'                 ,
        'LBL_LAST_14_DAYS'             => 'Last 14 Days'                ,
	'LBL_LAST_30_DAYS'             => 'Last 30 Days'                ,
	'LBL_LAST_60_DAYS'             => 'Last 60 Days'                ,
	'LBL_LAST_90_DAYS'             => 'Last 90 Days'                ,
	'LBL_LAST_120_DAYS'            => 'Last 120 Days'               ,
	'LBL_NEXT_7_DAYS'             => 'Next 7 Days'                ,   
	'LBL_NEXT_14_DAYS'             => 'Next 14 Days'                ,
	'LBL_NEXT_30_DAYS'             => 'Next 30 Days'                ,
	'LBL_NEXT_60_DAYS'             => 'Next 60 Days'                ,
	'LBL_NEXT_90_DAYS'             => 'Next 90 Days'                ,
	'LBL_NEXT_120_DAYS'            => 'Next 120 Days'               ,
	'LBL_OWNER'                    => 'Owner'                       ,
	'LBL_CREATED_ON'               => 'Created On'                  ,
	'LBL_MODIFIED_ON'              => 'Modified On'                 ,
	'LBL_BEFORE_EVENT'             => 'Before Event'                ,
	'Upcoming Activities'          => 'Upcoming Activities'         ,
	'Overdue Activities'           => 'Overdue Activities'          ,
	'Funnel'                       => 'Funnel'                      ,
	'Potentials by Stage'          => 'Opportunities by Stage'      ,
	'Pipelined Amount'             => 'Sales Pipeline'              ,
	'Total Revenue'                => 'Total Revenue'               ,
	'Top Potentials'               => 'Top Potentials'              ,
	'Forecast'                     => 'Forecast'                    ,
	'Leads Created'                => 'Leads Created'               ,
	'Leads by Status'              => 'Leads by Status'             ,
	'Leads by Source'              => 'Leads by Source'             ,
	'Leads by Industry'            => 'Leads by Industry'           ,
	'Tickets by Status'            => 'Tickets by Status'           , // TODO: Review
	'Open Tickets'                 => 'Open Tickets'                , // TODO: Review
	'LBL_EXPORT_ALL_DATA'          => 'Export all data'             ,
	'LBL_EXPORT_DATA_IN_CURRENT_PAGE' => 'Export data in current page' ,
	'LBL_EXPORT_SELECTED_RECORDS'  => 'Export Selected Records'     ,
	'LBL_EXPORT_RECORDS'           => 'Export Record Types'         ,
	'LBL_NO_RECORD_SELECTED'       => 'No record selected.'         ,
	'LBL_CAN_NOT_REMOVE_DEFAULT_WIDGET' => 'Cannot remove default widget',
	'LBL_CUSTOM_VIEW_NAME_DUPLICATES_EXIST' => 'filter already exists'       ,
        'LBL_EXPORT_CURRENCY_TOOLTIP_TEXT'=>'For exporting Currency values in Line items, Vtiger will use this setting to export as this currency. Any currency values outside the line items tables, will be exported as in User\'s preferred currency (selected in \'My Preferences\')',
        'LBL_EXPORT_LINEITEM_CURRENCY'=>'Choose Currency (For Line Item Values)',
        'LBL_EXPORT_USER_CURRENCY' =>' My preferred Currency',
        'LBL_EXPORT_RECORD_CURRENCY'=>'Currency specified in Record',
	'LBL_EXPORT_FORMAT' => 'Export format',
	'LBL_EXPORT_DATA' => 'Export Data',

	'LBL_ADD_MANAGE_MODULES'       => 'Add / Manage Modules'        ,
	'Account Name'                 => 'Organisation Name'           ,
	'Add Comment'                  => 'Add Comment'                 ,
	'Adjustment'                   => 'Adjustment'                  ,
	'Annual Revenue'               => 'Annual Revenue'              ,
	'Apparel'                      => 'Apparel'                     ,
	'Banking'                      => 'Banking'                     ,
	'Billing Address'              => 'Invoice Address'             ,
	'Billing City'                 => 'Invoice City'                ,
	'Billing Code'                 => 'Invoice Postal Code'         ,
	'Billing Country'              => 'Invoice Country'             ,
	'Billing Po Box'               => 'Invoice P.O. Box'            ,
	'Billing State'                => 'Invoice State'               ,
	'Biotechnology'                => 'Biotechnology'               ,
	'FedEx'                        => 'FedEx'                       ,
	'UPS'                          => 'UPS'                         ,
	'USPS'                         => 'USPS'                        ,
	'DHL'                          => 'DHL'                         ,
	'BlueDart'                     => 'BlueDart'                    ,
	'Carrier'                      => 'Carrier'                     ,
	'Category'                     => 'Category'                    ,
	'Chemicals'                    => 'Chemicals'                   ,
	'City'                         => 'City'                        ,
	'Cold Call'                    => 'Cold Call'                   ,
	'Existing Customer'            => 'Existing Customer'           ,
	'Self Generated'               => 'Self Generated'              ,
	'Employee'                     => 'Employee'                    ,
	'Partner'                      => 'Partner'                     ,
	'Public Relations'             => 'Public Relations'            ,
	'Direct Mail'                  => 'Direct Mail'                 ,
	'Conference'                   => 'Conference'                  ,
	'Trade Show'                   => 'Trade Show'                  ,
	'Web Site'                     => 'Web Site'                    ,
	'Word of mouth'                => 'Word of mouth'               ,
	'Other'                        => 'Other'                       ,
	'--None--'                     => '--None--'                    ,
	'Acquired'                     => 'Acquired'                    ,
	'Active'                       => 'Active'                      ,
	'Market Failed'                => 'Market Failed'               ,
	'Project Cancelled'            => 'Project Cancelled'           ,
	'Shutdown'                     => 'Shutdown'                    ,
	'Communications'               => 'Communications'              ,
	'Construction'                 => 'Construction'                ,
	'Consulting'                   => 'Consulting'                  ,
	'Education'                    => 'Education'                   ,
	'Electronics'                  => 'Electronics'                 ,
	'Energy'                       => 'Energy'                      ,
	'Engineering'                  => 'Engineering'                 ,
	'Entertainment'                => 'Entertainment'               ,
	'Environmental'                => 'Environmental'               ,
	'Finance'                      => 'Finance'                     ,
	'Food & Beverage'              => 'Food & Beverage'             ,
	'Government'                   => 'Government'                  ,
	'Healthcare'                   => 'Healthcare'                  ,
	'Hospitality'                  => 'Hospitality'                 ,
	'Insurance'                    => 'Insurance'                   ,
	'Machinery'                    => 'Machinery'                   ,
	'Manufacturing'                => 'Manufacturing'               ,
	'Media'                        => 'Media'                       ,
	'Not For Profit'               => 'Not For Profit'              ,
	'Recreation'                   => 'Recreation'                  ,
	'Retail'                       => 'Retail'                      ,
	'Shipping'                     => 'Shipping'                    ,
	'Technology'                   => 'Technology'                  ,
	'Telecommunications'           => 'Telecommunications'          ,
	'Transportation'               => 'Transportation'              ,
	'Utilities'                    => 'Utilities'                   ,
	'Contact Name'                 => 'Contact Name'                ,
	'Conversion Rate'              => 'Conversion Rate'             ,
	'Shipping Address'             => 'Delivery Address'            ,
	'Shipping City'                => 'Delivery City'               ,
	'Shipping State'               => 'Delivery State'              ,
	'Shipping Code'                => 'Delivery Postal Code'        ,
	'Shipping Country'             => 'Delivery Country'            ,
	'Shipping Po Box'              => 'Delivery P.O. Box'           ,
	'Country'                      => 'Country'                     ,
	'Created'                      => 'Created'                     ,
	'Approved'                     => 'Approved'                    ,
	'Delivered'                    => 'Delivered'                   ,
	'Cancelled'                    => 'Cancelled'                   ,
	'Currency'                     => 'Currency'                    ,
	'LBL_BASE_CURRENCY'            => 'Base currency'               ,
	'Discount Percent'             => 'Discount Percent'            ,
	'Discount Amount'              => 'Discount Amount'             ,
	'Item Discount Amount'         => 'Item Discount Amount'        ,
	'Item Discount Percent'        => 'Item Discount Percent'       ,
	'Due Date'                     => 'Due Date'                    ,
	'Due Date & Time'              => 'Due Date & Time'             ,
	'Email'                        => 'Email'                       ,
	'Secondary Email'              => 'Secondary Email'             ,
	'Other Email'                  => 'Other Email'                 ,
	'Email Opt Out'                => 'Email Opt Out'               ,
    'Is Converted From Lead'       => 'Is Converted From Lead'      ,
	'Expected Close Date'          => 'Expected Close Date'         ,
	'Fax'                          => 'Fax'                         ,
	'Last Name'                    => 'Last Name'                   ,
	'First Name'                   => 'First Name'                  ,
	'High'                         => 'High'                        ,
	'Low'                          => 'Low'                         ,
	'In Progress'                  => 'In Progress'                 ,
	'Subject'                      => 'Subject'                     ,
	'Terms & Conditions'           => 'Terms & Conditions'          ,
	'Item Name'                    => 'Item Name'                   ,
	'Quantity'                     => 'Quantity'                    ,
	'List Price'				   => 'Selling Price'				,
	'Image'						   => 'Image'						,
	'Purchase Cost'				   => 'Purchase Cost'				,
	'Margin'					   => 'Margin'						,
	'Item Comment'                 => 'Item Comment'                ,
	'Tax1'                         => 'Tax1'                        ,
	'Tax2'                         => 'Tax2'                        ,
	'Tax3'                         => 'Tax3'                        ,
	'Excise Duty'                  => 'Excise Duty'                 ,
	'Total'                        => 'Total'                       ,
	'Sub Total'                    => 'Sub Total'                   ,
	'Tax Type'                     => 'Tax Type'                    ,
	'S&H Amount'                   => 'S&H Amount'                  ,
	'Status'                       => 'Status'                      ,
	'Vendor Name'                  => 'Vendor Name'                 ,
	'LBL_ADDRESS_INFORMATION'      => 'Address Details'             ,
	'LBL_DESCRIPTION_INFORMATION'  => 'Description Details'         ,
	'LBL_TERMS_INFORMATION'        => 'Terms & Conditions'          ,
	'LBL_PRICING_INFORMATION'      => 'Pricing Information'         ,
	'LBL_RELATED_PRODUCTS'         => 'Product Details'             ,
	'LBL_REMINDER_INFORMATION'     => 'Reminder Details'            ,
	'LBL_FOLDER_SAVED'             => 'Folder saved'                ,
	'LBL_FOLDER_EXISTS'            => 'Folder already exists'       ,
	'LBL_FOLDER_DELETED'           => 'Folder deleted'              ,
	'LBL_EDIT_FOLDER' => 'Edit Folder',
	'Lead Source'                  => 'Lead Source'                 ,
	'Mobile'                       => 'Mobile'                      ,
	'Notify Owner'                 => 'Notify Owner'                ,
	'Other Phone'                  => 'Other Phone'                 ,
	'Phone'                        => 'Phone'                       ,
	'State'                        => 'County'                      ,
	'Po Box'                       => 'P.O. Box'                    ,
	'Postal Code'                  => 'Postal Code'                 ,
	'Potential Name'               => 'Opportunity Name'            ,
	'Priority'                     => 'Priority'                    ,
	'Product Name'                 => 'Product Name'                ,
	'Rating'                       => 'Rating'                      ,
	'Related To'                   => 'Related To'                  ,
	'Type'                         => 'Type'                        ,
	'Reviewed'                     => 'Reviewed'                    ,
	'Salutation'                   => 'Salutation '                 ,
	'Street'                       => 'Street'                      ,
	'Support Start Date'           => 'Support Start Date'          ,
	'Support Expiry Date'          => 'Support Expiry Date'         ,
	'Sales Start Date'             => 'Sales Start Date'            ,
	'Sales End Date'               => 'Sales End Date'              ,
	'Open Ticktes'                 => 'Open Tickets'                , // TODO: Review
	'LBL_SELECT_STATUS'            => 'Select Status'               ,
	'LBL_VTIGER_CRM_HONEST_OPEN_SOURCE' => 'vtiger CRM On Demand'        ,
	'SINGLE_Accounts'              => 'Organisation'                , // TODO: Review
	'SINGLE_Contacts'              => 'Contact'                     , // TODO: Review
	'LBL_Sun'                      => 'Sun'                         , // TODO: Review
	'LBL_Mon'                      => 'Mon'                         , // TODO: Review
	'LBL_Tue'                      => 'Tue'                         , // TODO: Review
	'LBL_Wed'                      => 'Wed'                         , // TODO: Review
	'LBL_Thu'                      => 'Thu'                         , // TODO: Review
	'LBL_Fri'                      => 'Fri'                         , // TODO: Review
	'LBL_Sat'                      => 'Sat'                         , // TODO: Review
	'LBL_Jan'                      => 'Jan'                         , // TODO: Review
	'LBL_Feb'                      => 'Feb'                         , // TODO: Review
	'LBL_Mar'                      => 'Mar'                         , // TODO: Review
	'LBL_Apr'                      => 'Apr'                         , // TODO: Review
	'LBL_May'                      => 'May'                         , // TODO: Review
	'LBL_Jun'                      => 'Jun'                         , // TODO: Review
	'LBL_Jul'                      => 'Jul'                         , // TODO: Review
	'LBL_Aug'                      => 'Aug'                         , // TODO: Review
	'LBL_Sep'                      => 'Sep'                         , // TODO: Review
	'LBL_Oct'                      => 'Oct'                         , // TODO: Review
	'LBL_Nov'                      => 'Nov'                         , // TODO: Review
	'LBL_Dec'                      => 'Dec'                         , // TODO: Review
	'LBL_CALENDAR_SETTINGS'        => 'Calendar Settings'           , // TODO: Review
        'Reminder Interval'            => 'Popup Reminder Interval'     ,
	'HelpDesk'                     => 'Tickets'                     , // TODO: Review
	'LBL_TAG_CLOUD'                => 'Tag Cloud'                   , // TODO: Review
	'LBL_NO_RECORDS'               => 'No Records'                  , // TODO: Review
	'LBL_NO_RELATED'               => 'No Related'                  , // TODO: Review
	'LBL_GLOBAL_SEARCH_MAX_MESSAGE' => 'Only the first 100 results of all modules are shown below. For module specific results, please select respective module and search', // TODO: Review
	'LBL_GLOBAL_SEARCH_MAX_MESSAGE_FOR_MODULE' => 'Only the first 100 results are shown below. Please do Advanced Search if you are not satisfied with the result', // TODO: Review
	'LBL ACTION'                   => 'Action'                      , // TODO: Review
	'LBL_NOTE'                     => 'Note'                        , // TODO: Review
	'LBL_SELECT_OPTION'            => 'Select an Option'            , // TODO: Review
	'LBL_TOOLTIP'                  => 'Tooltip Management'          , // TODO: Review
	'LBL_MODULE_SEQUENCE_NUMBERING' => 'Module Sequence Numbering'   , // TODO: Review
	'LBL_CUSTOM_FIELD_MAPPING'     => 'Custom Field Mapping'        , // TODO: Review
	'LBL_WEBFORMS'                 => 'WebForms'                    , // TODO: Review
	'SINGLE_Emails'                => 'Email'                       ,
	'Emails'                       => 'Emails'                      , // TODO: Review
	'LBL_SELECT_EMAIL_IDS'         => 'Select Email Addresses'      , // TODO: Review
	'LBL_SUBJECT'                  => 'Subject'                     , // TODO: Review
	'LBL_ATTACHMENT'               => 'Attachment'                  , // TODO: Review
	'LBL_BROWSE_CRM'               => 'Browse CRM'                  , // TODO: Review
	'LBL_SEND'                     => 'Send'                        , // TODO: Review
	'LBL_SAVE_AS_DRAFT'            => 'Save as Draft'               , // TODO: Review
	'LBL_GO_TO_PREVIEW'            => 'Go to Preview'               , // TODO: Review
	'LBL_SELECT_EMAIL_TEMPLATE'    => 'Select Email Template'       , // TODO: Review
	'LBL_COMPOSE_EMAIL'            => 'Compose Email'               , // TODO: Review
	'LBL_CC'                       => 'Cc'                          , // TODO: Review
	'LBL_BCC'                      => 'Bcc'                         , // TODO: Review
	'LBL_ADD_CC'                   => 'Add Cc'                      , // TODO: Review
	'LBL_ADD_BCC'                  => 'Add Bcc'                     , // TODO: Review
	'LBL_MAX_UPLOAD_SIZE'          => 'Maximum upload size is'      , // TODO: Review
	'LBL_EXCEEDED'                 => 'Exceeded'                    , // TODO: Review

	//Translations used for Export to Pdf
	'Valid Date' => 'Valid Date',
	'Phone: ' => 'Phone: ',
	'Issued Date' => 'Issued Date',
	'Shipping & Handling Charges' => 'Shipping & Handling Charges',
	'Shipping & Handling Tax:' => 'Shipping & Handling Tax:',
	'Discount'=>'Discount',
	'Net Total' => 'Net Total',
	'Product Code'=>'Product Code',
	'Customer Name'=>'Customer Name',
	'Price'=>'Price',
	'Tax:' => 'Tax:',
	'Contact Name' => 'Contact Name',
	'Grand Total:' => 'Grand Total:',
	'Fax: ' => 'Fax: ',
	'Website: ' => 'Website: ',
	'Tax' => 'Tax',
        'LBL_ALPHABETS' => 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z',

	//Realted tab strings
	'Service Contracts' => 'Service Contracts',
	'Projects' => 'Projects',
	'Sales Order' => 'Sales Order',
	'Purchase Order' => 'Purchase Order',
	'Payments' => 'Payments',
	'List and Campaigns' => 'List and Campaigns',
	'Project Tasks' => 'Project Tasks',
	'Project Milestones' => 'Project Milestones',

	'Labels Editor' => 'Labels Editor',
	'LBL_IGNORE_EMPTY_VALUES' =>'Ignore empty values',

	//Related tabs of Products
	'Product Bundles' => 'Product Bundles',
	'Parent Product' => 'Parent Product',
	'LBL_PRODUCT_BUNDLE' => 'Product Bundle',
	'LBL_EDIT_QUANTITY' => 'Edit Quantity',
	'LBL_ADD_TO_PRODUCTS' => 'Add Products',

	'LBL_MANAGE_USERS' => 'Manage Users',
	'LBL_TRANSFER_OWNERSHIP' => 'Transfer Ownership',
	'LBL_SELECT_RELATED_MODULES' => 'Select Related Modules',

	'LBL_CUSTOMIZE_MAIN_MENU' => 'Customise Main Menu', //TODO REVIEW

	//Comments Field Labels for Workflow
	'Comment' => 'Comment',
	'Last Comment' => 'Last Comment',
	'Last 5 Comments' => 'Last 5 Comments',
	'All Comments' => 'All Comments',

	//Feedback on removing old version
	'LBL_OLD_VERSION_REMOVED_SOON' => 'Important Note on Old look',
	'LBL_FEEDBACK_ON_REMOVING_OLD_VERSION' => 'We are happy to share that old look will be available until February, 2014 . We added the following features to the new look recently<br><br>1. Pivot Reports<br>2. Custom Charts<br>3. Quick Search in Lists<br><br>If you have suggestions on new look, please share with us below.',
	'LBL_FEEDBACK_PLACEHOLDER' => 'Share your suggestions here..',
	'LBL_SUBMIT_FEEDBACK' => 'Submit Feedback',
	'LBL_DONT_SHOW_AGAIN' => 'Do not show this again',
	'LBL_CONTINUE_TO_OLD_LOOK' => 'Continue to Old Look',

        'LBL_TRANSFER_OWNERSHIP' => 'Transfer Ownership',

    //Products Popup View
    'NOT_A_BUNDLE' => 'Not a bundle',
    'LBL_SUB_PRODUCTS' => 'Sub Products',
    'LBL_MARK_AS_HELD' => 'Mark As Held',
    'LBL_SMS_MAX_CHARACTERS_ALLOWED' => 'Maximum 160 characters are allowed for text message',
    'LBL_HIDE_COMPLETED_EVENTS' => 'Hide Completed Calendar Events',
    'LBL_SETUP_WEBFORMS'                 => 'Setup Webfroms'              ,
    'LBL_SPECIAL_OPTIONS' => 'Special Options',
    'LBL_PARENT_OWNER' => 'Parent Record Owner',
	'LBL_PASSWORD_LINK_EXPIRED_OR_INVALID_PASSWORD' => 'Password link has expired or you have entered invalid password',

    // Recurring Invoice
    'Half-Yearly' => 'Half-Yearly',
    'LBL_FULLSCREEN' => 'Full Screen',
    'LBL_MODULE_DISABLED'          => ' Module is disabled'     ,
    'Organization Name' => 'Organisation Name',
    'LBL_WEEK' => 'Week',
    // Convert Leads and Potentials
    'LBL_CONVERT_ERROR_TITLE' => 'Modules Disabled'            ,
	'CANNOT_CONVERT' => 'Cannot be converted'         ,
	'LBL_FOLLOWING_ARE_POSSIBLE_REASONS' => 'Following could be one of the possible reasons',
    'LBL_MANDATORY_FIELDS_ARE_EMPTY' => 'Some of the mandatory field value are empty',

    // SMSNotifier Phone Format Warning
    'LBL_PHONE_FORMAT_WARNING' => 'Please ensure that phone number is in international E.164 format',
    'LBL_PHONEFORMAT_WARNING_CONTENT' => 'The E.164 number formatting can have a maximum of fifteen digits and are usually written as follows: [+][country code][subscriber number including area code]
                                          For example, to convert a US phone number (415 599 2671) to E.164 format, one would need to add the \'+\' prefix and the country code (which is 1) in front of the number (+1 415 599 2671). In the UK and many other countries internationally, local dialing requires the addition of a 0 in front of the subscriber number. However, to use E.164 formatting, this 0 must be removed. A number such as 020 7183 8750 in the UK would be formatted as +44 20 7183 8750.',
    'LBL_WARNING' => 'Warning',

    'LBL_ORIGIN' => 'Origin',
    'SENT' => 'CRM',
    'SAVED' => 'Draft',
    'MailManager' => 'Mail Manager',
    'MAILSCANNER' => 'Mail Converter',
	'LBL_SENDER_NAME' => 'Sender Name',

    'Mobile Call' => 'Mobile Call',
	'Related To' => 'Related To',

    // Date Conditions
    'LBL_LESS_THAN_DAYS_AGO' => 'Less than days ago',
    'LBL_MORE_THAN_DAYS_AGO' => 'More than days ago',
    'LBL_IN_LESS_THAN' => 'In less than',
    'LBL_IN_MORE_THAN' => 'In More than',
    'LBL_DAYS_AGO' => 'Days ago',
    'LBL_DAYS_LATER' => 'Days Later',
    'LBL_LESS_THAN_HOURS_BEFORE' => 'Less than hours before',
    'LBL_LESS_THAN_HOURS_LATER' => 'Less than hours later',
    'LBL_MORE_THAN_HOURS_BEFORE' => 'More than hours before',
    'LBL_MORE_THAN_HOURS_LATER' => 'More than Hours Later',
    'LBL_INTERNAL_COMMENT' => 'Internal Comment',
	'LBL_NOTE_EXISTING_ATTACHMENTS_WILL_BE_REPLACED' => 'Note : Existing attachments(images/files) will be replaced',
    //common standard fields
    'Created By' => 'Created By',
	'LBL_SEND_PDF_FOR_SIGNING' => 'Send PDF for signing',
	'LBL_INCLUDE_SIGNATURE_INFO' => 'Signature set in My Preferences will be appended to the bottom of the email',
	'LBL_INCLUDE_SIGNATURE' => 'Include Signature',
	'LBL_CLICK_HERE'=>'click here',
    
    // Social Module Strings
    'LBL_TWEETS' => 'Tweets',
    'LBL_FAVOURITES' => 'Favourites',
    'LBL_FOLLOWING' => 'Following',
    'LBL_FOLLOWERS' => 'Followers',
    'LBL_VIEW_FULL_PROFILE' => 'View Full Profile',
    'LBL_LOCATION' => 'Location',
    'LBL_DESCRIPTION' => 'Description',
    'LBL_JOINED' => 'Joined',
    'LBL_SEARCH_PROFILES_IN_TWITTER' => 'Search Profiles In Twitter',
    'LBL_CHOOSE_ANOTHER_PROFILE' => 'Choose Another Profile',
    'LBL_ADD_TICKET' => 'Add Ticket',
    'LBL_ADD_OPPORTUNITY' => 'Add Opportunity',
    'LBL_RETWEET' => 'Retweet',
    'LBL_RETWEETS' => 'Retweets',
    'LBL_UNDO_RETWEET' => 'Undo Retweet',
    'LBL_FAVOURITE' => 'Favourite',
    'LBL_UNDO_FAVOURITE' => 'Undo Favourite',
    'LBL_TWITTER_HANDLER_MSG' => 'To see this contact\'s profile summary and history add their Twitter handler or search profiles using the link below.',
    'LBL_ADD_EVENT_OR_TODO' => 'Add Event/Todo',
    'LBL_ADD_TICKET_CONTACT' => 'Add Ticket + Contact',
    'LBL_ADD_OPPORTUNITY_CONTACT' => 'Add Opportunity + Contact',
    'LBL_SOCIAL_TWITTER_WIDGET' => 'Twitter Activity',
    'LBL_TWITTER_HANDLER_DETAILS' => 'Twitter Handler Details',
    'LBL_PRIMARY_TWITTER' => 'Primary Twitter',
    'LBL_ADD_TWITTER_HANDLER' => 'Add Twitter Handler',
    'LBL_VIEW_TICKET' => 'View Ticket',
    'LBL_VIEW_OPPORTUNITY' => 'View Opportunity',
    'LBL_CLICK_TO_SELECT_PROFILE' => 'Click to select profile',
    // Module field to store Source of Record
    'Source' => 'Source',

    
    'LBL_DEFAULT_REPLY_TO' => 'Default Reply To for Emails',
    'outgoing_server_from_email' => 'Outgoing Server From Email',
    'hepldesk_support_email' => 'Helpdesk Support Email-Id',
    'user_primary_email' => 'User Primary Email',
    'LBL_DEFAULT_REPLY_TO_INFO' => "This setting is applicable only for direct emails from CRM. It doesn't affect emails sent from workflows, email campaigns, etc.",
    'LBL_INVALID_IMAGE' => 'Invalid Image',
    'LBL_NEXT'      => 'Next',
    'LBL_FINISH' => 'Finish',
	
	'VAT' => 'VAT',
	'Sales' => 'Sales',
	'Service' => 'Service',
	'Pre Tax Total' => 'Pre Tax Total',
	'Received' => 'Received',
	'Balance' => 'Balance',
	'S&H Amount' => 'Charges',
	'S&H Percent' => 'Taxes On Charges',
	'Tax Region' => 'Tax Region',
    
    //Singular Modulenames
    'SINGLE_Potentials' => 'Opportunity',
    'SINGLE_HelpDesk' => 'Ticket',
    'SINGLE_Accounts' => 'Organisation',
    'SINGLE_Contacts' => 'Contact',
    'SINGLE_Project' => 'Project',
    'LBL_ROLLUP_COMMENTS_INFO' => "If Roll up is set to 'On' comments on related records will be shown. 
                                   For example, if you are viewing comments on an Organisation record, comments added to related Contacts, Opportunities, Tickets, ..etc would also be displayed.",
    'LBL_ROLLUP_COMMENTS' => "Rollup Comments",
    'group' => 'Group',
    'individual' => 'Individual',
    //Comment with Attachements
    'LBL_VIEW_FILE'=>'View file',
    'LBL_DOWNLOAD_FILE' => 'Download file',
    'LBL_PREVIEW_NOT_AVAILABLE' => 'Preview Not Available',
    'LBL_PREVIEW_SUPPORTED_FILES' => '<b><strong>Supported File Types : </strong></b><br><br><b>Pdf files</b><br><b>Text files - </b>txt,csv,ics<br><b>Open Document Files - </b>open document text(odt),open document spreadsheet(ods) and open document presentation(odp)<br><b>Multimedia files - </b>image, audio & video files<br>',
    'LBL_PREVIOUS' => 'Previous',
    'LBL_NEXT' => 'Next',
    'Mailing Address' => 'Mailing Address',
    'Other Address' => 'Other Address',
    'Workflows' => 'Workflows',
    'Primary Twitter' => 'Primary Twitter',
	// Extensions
    'LBL_SYNC_LOG' => 'Sync Log',
    'LBL_SYNC_SETTINGS' => 'Sync Settings',
    'LBL_SYNC_NOW' => 'Sync Now',
    'LBL_DATE' => 'Date',
    'LBL_TIME' => 'Time',
    'LBL_SKIPPED' => 'Skipped',
    'vt_create' => 'Vtiger Created',
    'vt_update' => 'Vtiger Updated',
    'vt_delete' => 'Vtiger Deleted',
    'vt_skip' => 'Vtiger Skipped',
    'app_create' => 'Application Created',
    'app_update' => 'Application Updated',
    'app_delete' => ' Application Deleted',
    'app_skip' => 'Application Skipped',
    'LBL_DOWNLOAD_AS_CSV' => 'Download As Csv',
    'LBL_SOURCE_MODULE' => 'Source Module',
    'LBL_RECORD_NAME' => 'Record Name',
    'LBL_REASON' => 'Reason',
    'LBL_SELECT_MODULES_TO_SYNC' => 'Select modules to sync',
    'LBL_DATA' => 'Data',
    'LBL_ENABLE_SYNC' => 'Enable Sync',
    'LBL_FIELD_MAPPING' => 'Field Mapping',
    'LBL_SYNC_DIRECTION' => 'Sync Direction',
    'LBL_SYNC_BOTH_WAYS' => 'Sync Both Ways',
    'LBL_SAVE_SETTINGS' => 'Save Settings',
    'LBL_CONFIGURE' => 'Configure',
    'LBL_VIEW' => 'View',
    'LBL_CHANGE_USER' => 'Change User',
    'LBL_SELECT_COLOR' => 'Select Color',
    'LBL_CREATION' => 'creation',
	'LBL_STARRED' => 'Starred',
	'LBL_UNSTARRED' => 'Unstarred',
    'LBL_EDIT_EMAIL_PREFERENCE_TOOLTIP' => 'Edit these preferences from Settings dropdown in modules detail or list view',
	'LBL_SYSTEM' =>'System',

  'LBL_LINKED' => 'Linked',
  'LBL_ADDING_NEW' => 'Adding new',
  'LBL_LESS' => 'Less',
  'LBL_COMMENT' => 'Comment',
  'LBL_NOT_STARRED' => 'Follow',
  'LBL_QUICK_VIEW' => 'Quick View',
  'LBL_NOTIFICATION_CENTER' => 'Notification Center',
	'LBL_NOTIFICATION' => 'Notification',
	'LBL_STARRED_RECORD_TO' => '%s to %s',
	'LBL_STARRED_RECORD_UPDATED' => '%s updated %s',
  'LBL_EDIT_REASON' => 'Edit reason',
  'LBL_CONTACT' => 'CONTACT MANAGEMENT',
  'LBL_NO_ATTACHMENTS' => 'No Attachments',
  'LBL_REARRANGE_DASHBOARD_TABS' => 'Rearrange Tabs',
  'LBL_DONE' => 'Done',
  'LBL_DELETE_DASHBOARD_TAB' => 'Delete Tab',
  'LBL_DASHBOARD_TAB_ALREADY_EXIST' => 'Tab Name Already Exist',
  'LBL_TABS_LIMIT_EXCEEDED' => 'Sorry! Can\'t add more than 10 tabs',
  'LBL_TODOS' => 'Tasks',
  'LBL_VIDEOS' => 'Videos',
  'LBL_SAME_TAG_EXISTS' => 'Duplicate tag exist',
  'LBL_MAKE_PUBLIC' => 'Make Public',
  'LBL_PROFILE_PASSWORD' => 'Profile / Password',
  'LBL_CANT_MOVE_FROM_PUBLIC_TO_PRIVATE' => 'Cannot able to move from Public tag to Private tag.',
  'LBL_EDIT_TAG' => 'Edit Tag',
  'LBL_NO_TAG_EXISTS' => 'No Tag Exists',
  'LBL_HISTORY' => 'Touchpoints',
  'LBL_KEY_FIELD' => 'Key Field',
  'LBL_NAME_EMAIL' => 'Name and Email',
  'LBL_PLEASE_SELECT_MODULE' => 'Please select any module to search',
  'LBL_IS_REMOVED' => 'is Removed',
  'LBL_REASON_FOR_CHANGING_COMMENT' => 'Reason for changing comment',
  'LBL_APPLBL_NONEROVE' => 'Approve',
  'Add Note' => 'Add Document',
  'LBL_form' => 'from',
  'LBL_to' => 'to',
  'LBL_DAY(S' => 'day(s',
  'LBL_HOUR(S' => 'hour(s',
  'SINGLE_Users' => 'User',
  'LBL_NOTEPAD' => 'Notepad',
  'LBL_NOTEPAD_NAME' => 'Notepad Name',
  'LBL_NOTEPAD_CONTENT' => 'Notepad Content',
  'LBL_LAST_SAVED_ON' => 'Last saved on',
  'Notebook' => 'Notepad',
  'LBL_MY' => 'My',
  'LBL_IS_EMPTY' => 'is empty',
  'LBL_MODIFIED' => 'Modified',
  'Funnel Amount' => 'Total Amount by Sales stage',
  'LBL_TYPE_AND_SEARCH' => 'Type and Search',
  'LBL_CUSTOMIZE' => 'Customise:',
  'LBL_LABELS' => 'Labels',
  'LBL_WORKFLOWS' => 'Workflows',
  'LBL_PICKLIST' => 'Picklists',
  'LBL_BLANK' => '-Blank-',
  'LBL_ACTION' => 'Action',
  'LBL_OPERATION_NOT_PERMITTED' => 'Operation not permitted',
  'LBL_MERGE' => 'Merge',
  'LBL_MERGING_CRITERIA_SELECTION' => 'Merging Criteria Selection',
  'LBL_AVAILABLE_FIELDS' => 'Available Fields',
  'LBL_MERGE_RECORDS_DESCRIPTION' => 'The primary record will be retained after the merge. You can select the column to retain the values.
										The other record will be deleted but the related information will be merged.',
  'LBL_MERGE_RECORDS_IN' => 'Merge Records In',
  'LBL_FIELDS' => 'Fields',
  'LBL_RECORD' => 'Record',
  'LBL_NO_DUPLICATED_FOUND' => 'No duplicates found',
  'LBL_MERGE_SELECT' => 'Merge Select',
  'LBL_BACK_TO_PRODUCTS' => 'Back to products',
  'LBL_ASSIGNED_TO' => 'Assigned To',
  'LBL_LEFT_PANEL_SHOW_HIDE' => 'Left Panel Show/Hide',
  'SMSNotifier' => 'SMS Notifier',
  'LBL_NO_MORE_RESULTS' => 'No more results!',
  'LBL_CLICK_TO_EDIT' => 'Click to edit',
  'LBL_SIGNATURE_BLOCK' => 'Signature',
  'LBL_BASIC_INFORMATION' => 'Basic Information',
  'LBL_SELCT_EMAIL_RECIPIENTS' => 'Select Email Recipients',
  'LBL_REMEMBER_MY_PREF' => 'Remember my preference',
  'LBL_RECIPIENT_PREFS' => 'Recipient Preferences',
  'LBL_EMAIL_RECIPIENT_PREFS' => 'Email Recipient Preferences',
  'LBL_ERROR_SAVING_PREF' => 'Error in saving preferences. Please try later!',
  'LBL_NO_PREF_GIVEN' => 'No preferences given!',
  'LBL_PLEASE_ADD_EMAIL_FIELDS' => 'Please add email fields and try again',
  'LBL_RECIPIENT_SAVE_MESSAGE' => 'Save successful.These preferences will be treated as recipient email addresses when you send email from this module.',
  'LBL_PREF_RESET_MESSAGE' => 'Your recipient email preferences has been reset!',
  'LBL_COMPANY_DETAILS' => 'Company Details',
  'COMPANY_LOGO_HELP_TEXT' => 'Please upload your lovely company logo. <br>Besides showing your company logo on your CRM,<br>
                                    your company name and address details are used in <br>Email Campaigns (required to meet span regulations<br>
                                    and in Quotes.',
  'COMPANY_LOGO_HELP_TEXT_2' => 'You can edit company details later from <br>
                                    \'CRM Settings > Templates > Company Details\' page',
  'LBL_CHOOSE_PREFERENCES' => 'Choose your Preferences',
  'PREFERENCES_HELP_TEXT' => 'Base Currency - Choose your primary currency. If you use multiple<br> 
                              currencies, all the values are converted to base currency  and stored,<br>
                              using the conversion rate configured in CRM.',
  'PREFERENCES_HELP_TEXT_2' => 'Personal preferences can be configured by each user in your team.<br>
                                  These include Timezone, Language, Date Format, Number Format.<br>
                                  Number Format references are used for Currencies and other <br>
                                  number fields in the CRM<br>
                                  You can edit your preferences later from \'User Name > My Preferences \'',
  'LBL_CANNOT_BE_CHANGED_LATER' => 'Cannot be changed later',
  'IMPORT_CONTACTS_GOOGLE_HELP_TEXT' => 'We can bring contacts from Google and <br> you can also enable bi-direction sync to keep our<br>
                                    Vtiger contacts and Google contacts(in selected group updated.<br>
                                    Click the button to authorise and get Contacts from Google.',
  'IMPORT_CONTACTS_CSV_HELP_TEXT' => 'You can import Contacts from CSV file.',
  'IMPORT_CONTACTS_CSV_HELP_TEXT2' => 'To Import Opportunities, Leads, Tickets, please look for Actions > Import button on any of the
                                         list views.',
  'LBL_DOEST_FIRST_ROW_HEADER' => 'Does first row in your file contains column headers?',
  'LBL_SELECT_CSV_FILE' => 'Select CSV file',
  'LBL_START_IMPORTING' => 'Start Importing',
  'LBL_PRIMARY' => 'Primary',
  'LBL_GOOGLE_SYNC_INTIATED_MSG' => 'Your import is scheduled, Your contacts will be imported shortly.<br> Proceeding to Next step will not interrupt the import.',
  'LBL_IMPORT_SYNC_INTIATED_MSG' => 'Your import is in progress. You will receive an email when import is completed.<br> Proceeding to Next step will not interrupt the import.',
  'LBL_TELL_US_ABOUT_YOU' => 'Help us by telling us about your Company',
  'TELL_US_ABOUT_YOU_HELP_TEXT' => 'We continue to make improvements to the CRM, and <br>
                                      knowing our users better will help us prioritise enhancements.',
  'TELL_US_ABOUT_YOU_HELP_TEXT_2' => 'The data you submitted here will not be revealed to anyone <Br>
                                        outside Vtiger.',
  'LBL_IMPORT_CONTACTS' => 'Import Contacts',
  'LBL_FROM_GOOGLE' => 'From Google',
  'LBL_FROM_CSV' => 'From CSV File',
  'LBL_GET_CONTACTS_FROM_GOOGLE' => 'Get Contacts From Google',
  'LBL_PHONE_NUMBER' => 'Phone Number',
  'LBL_NUMBER_OF_EMPLOYEES' => 'Number of Employees',
  'LBL_INDUSTRY' => 'Industry',
  'LBL_HELP_DESK_EMAIL_HELP_TEXT' => 'Ticket related notifications will be sent from this Email address',
  'LBL_SOCIAL_DETAILS' => 'Link to social networks to find new customers, and respond to queries',
  'LBL_SOCIAL_AUTHORIZE_HELP' => 'Connect with your companys twitter account to post your messages and track engagement',
  'LBL_SOCIAL_AUTHORIZE' => 'Connect with Twitter',
  'LBL_SOCIAL_LINKED' => 'Your Vtiger is now linked to',
  'LBL_ENTER_KEYWORDS_HELP' => 'Vtiger will scan twitter and find messages with these words',
  'LBL_ENTER_KEYWORDS' => 'Enter Keywords',
  'LBL_ADD_CASE_CONTACT' => 'Add Case + Contact',
  'LBL_VIEW_CASE' => 'View Case',
  'Engagement Score' => 'Engagement Score',
  'LBL_CLICK_HERE_TO_SELECT_ALL_RECORDS' => 'Select all records in this page',
  'LBL_CLICK_HERE_TO_MANAGE_LIST_COLUMNS' => 'Click here to manage List columns',
  'LBL_SHOW_MORE' => 'Show more',
  'LBL_DISPLAYING_RESULTS' => 'Displaying Results',
  'LBL_ADD_STAR' => 'Add Star',
  'LBL_REMOVE_STAR' => 'Remove Star',
  'LBL_UPDATE_LIST' => 'Update List',
  'LBL_SHARE_THIS_LIST' => 'Share the list',
  'LBL_ADD_USERS_ROLES' => 'Add Users, Roles...',
  'LBL_LISTS' => 'Lists',
  'LBL_SEARCH_FOR_LIST' => 'Search for List',
  'LBL_MY_LIST' => 'My List',
  'LBL_SHARED_LIST' => 'Shared List',
  'LBL_MERGE_SELECTED_RECORDS' => 'Merge selected records',
  'LBL_MATCH_CRITERIA' => 'Duplicate Search Criteria',
  'LBL_MATCH_FIELDS' => 'Match Fields',
  'LBL_EDIT_CUSTOM' => 'Edit List',
  'LBL_SHOW_MAP' => 'Show Map',
  'LBL_ADD_TAB' => 'Add Tab',
  'LBL_TAB_NAME' => 'Tab Name',
  'LBL_SHARED_TAGS_ACCESS' => 'Shared tags are accessible by all users in Vtiger',
  'LBL_GOTO_TAGS' => 'Go to Settings > My preferences > My Tags to Edit or Delete your private tags',
  'LBL_UNLINK' => 'Unlink',
  'LBL_SWITCH_TO_OLD' => 'Switch to old version',
  'LBL_CONFIG_COLUMNS' => 'Configure Columns',
  'LBL_SELECTED_FIELDS' => 'Selected Fields',
  'LBL_SEARCH_FIELDS' => 'Search Fields',
  'ExtensionStore' => 'Extensions Store',
  'LBL_EXTENSIONS' => 'Extensions',
  'LBL_CREATE_LIST' => 'Create a New List',
  'sent' => 'Sent',
  'accepted' => 'Accepted',
  'LBL_RECENT_COMMENTS' => 'Recent Comments',
  'LBL_ENGAGEMENT_HISTORY' => 'Touchpoint History',
  'LBL_NO_ENGAGEMENTS_FOUND' => 'No related Touchpoints',
  'LBL_MARKETING' => 'MARKETING',
  'LBL_SALES' => 'SALES',
  'LBL_PROJECT' => 'PROJECTS',
	'LBL_TOOLS' => 'TOOLS',
  'LBL_TAGS' => 'Tags',
  'LBL_SHARE_TAGS' => 'Public Tags',
  'LBL_SHARE_TAG' => 'Share Tag',
  'LBL_TAG_FOR' => 'Tag For %s',
  'LBL_CURRENT_TAGS' => 'Current Tags',
  'LBL_CREATE_NEW_TAG' => 'Create new tag',
  'LBL_ADD_TAG' => 'Add Tag',
  'LBL_REMOVE_TAG' => 'Remove Tag',
  'LBL_TAG_SEPARATOR_DESC' => 'Use comma to separate multiple tags',
  'LBL_ENTER_TAG_NAME' => 'Enter tag name',
  'LBL_ADD_NEW_TAG' => 'Add Tag',
  'LBL_SELECT_EXISTING_TAG' => 'Type here to select an existing tag',
  'LBL_ADD_OR_SELECT_TAG' => 'Add/Select Tag',
  'LBL_SELECT_FROM_AVAIL_TAG' => 'Select from available tags',
  'LBL_MARKET_PLACE' => 'Market Place',
  'EmailTemplates' => 'Email Templates',
  'LBL_BILLING' => 'Billing',
  'LBL_ENABLED' => 'Enabled',
  'LBL_CREATE_FILTER' => 'Create Filter',
  'LBL_IS' => 'is',
  'LBL_UPLOAD' => 'Upload',
  'LBL_ATTACH_FILES' => 'Attach Files',
  'LBL_KEY_FIELDS' => 'Key Fields',
  'LBL_ADD_TODO' => 'Add Task',
  'LBL_VIEW_DETAILS' => 'View Details',
  'LBL_HAPPENED_ON' => 'Happened On',
  'LBL_HAPPENED' => 'Happened',
  'LBL_TYPE' => 'Type',
  'LBL_STATUS' => 'Status',
  'LBL_CUSTOMER' => 'Related To',
  'LBL_ENGAGEMENTS' => 'Touchpoints',
  'LBL_PLEASE_SELECT_ATLEAST_ONE_OPTION' => 'Please select at least one option',
  'LBL_GOOGLE_MAP' => 'Google Map',
  'LBL_KEY_METRICS' => 'Key Metrics',
  'LBL_TEMPLATE_NAME' => 'Template Name',
  'LBL_MODULE' => 'Module',
  'LBL_IS_DEFAULT' => 'Default Template',
  'LBL_SELECT_RECORD_FIELD' => 'Select Record Field',
  'LBL_PREVIEW' => 'Preview',
  'LBL_UNLINKED' => 'Unlinked',
  'LBL_FOLLOW' => 'Follow',
  'LBL_UNFOLLOW' => 'Unfollow',
  'Any' => 'Any',
  'LBL_NA' => '-NA-',
  'LBL_DISABLED' => 'Disabled',
  'LBL_HELP_ANSWERS' => 'Answers',
  'LBL_HELP_ARTICLES' => 'Articles',
  'LBL_HELP_TOUR' => 'Tour',
  'LBL_NO_HELP_ARTICLE_FOUND' => 'Sorry, no Article found',
  'LBL_HELP_SEARCH' => 'Search Help',
  'LBL_HELP_BROWSE_ALL' => 'Browse all',
  'LBL_EXPORT_FILE_NAME' => 'Export Filename',
  'LBL_EXTENSION_NOT_ALLOWED_FOR_NONADMIN' => '%s Sync is allowed only for admin users',
  'SINGLE_Invoice' => 'Invoice',
  'SINGLE_SalesOrder' => 'Sales Order',
  'SINGLE_PurchaseOrder' => 'Purchase Order',
  'SINGLE_Quotes' => 'Quote',
	'LBL_POST_YOUR_COMMENT_HERE' => 'Post your comment here',
  'LBL_CLICK_TO_CALL' => 'Click-to-Call',
  'LBL_SHOW_TOTAL_NUMBER_OF_RECORDS' => 'Click to get total record counts',
  'LBL_GENERAL_FIELDS' => 'General Fields',
  'LBL_ROLL_UP' => 'Roll up',
  'LBL_TOUCH_POINTS' => 'Touchpoints',
  'LBL_EMAIL_SUPPORT'            => 'Email Support'               , 
  'LBL_NO_ENTITIES_FOUND'        => 'No %s found'                 ,

  'LBL_DAY' => 'day',
  'LBL_HOUR' => 'hour',
  'LBL_LIST_VIEW' => 'List View',
  'LBL_THUMBNAIL_VIEW' => 'Thumbnail View',
  'LBL_CHART_VIEW' => 'Chart View',


  'LBL_DAY(S)' => 'day(s)',
  'LBL_HOUR(S)' => 'hour(s)',
  'LBL_SLA_INFORMATION' => 'SLA Information',
  'LBL_TO_USE_SWITCH_TO_NEW_LOOK' => 'To use <b>%s</b>, we recommend you to Switch to new look.',
	'LBL_DELETE_USER_CONFIRMATION' => 'When a User is deleted, user will be marked as "Inactive" and no new records can be assigned to the User, and the user will not be able to login. Are you sure you want to delete?',

	'LBL_DUPLICATES' => 'Duplicates',
	'LBL_DUPLICATES_DETECTED' => 'Duplicate(s) detected!',
	'LBL_DUPLICATES_FOUND_MESSAGE' => 'This %s cannot be saved since duplicate %s exists in Vtiger with matching values for %s.',
	'LBL_VTIGER_NOTIFICATION' => 'Message from : Vtiger System Notifications',
	'LBL_DUPLICATION_FAILURE_FROM_WORKFLOWS' => 'The following %s could not be saved from "%s" workflow',
	'LBL_DUPLICATION_FAILURE_FROM_WEBFORMS' => 'The following %s could not be saved from "%s" webform',
	'LBL_DUPLICATION_FAILURE_FOR_ADMIN' => 'You can %s to modify duplicate prevention rules.',
	'LBL_DUPLICATION_FAILURE_FOR_NON_ADMIN' => 'Contact your administrator for revising the duplicate rules',
	'LBL_DUPLICATE_RECORD_LISTS' => 'Duplicate %s(s) :',
);
$jsLanguageStrings = array(
	'JS_EMAIL_SERVER_CONFIGURATION' => 'Please configure your outgoing server settings from the settings page',
	'JS_SMS_SERVER_CONFIGURATION'  => 'Please configure your SMS notifier from the SMS notifier settings page',
	'JS_PLEASE_SELECT_ONE_RECORD'  => 'Please select at least one record',
	'JS_PLEASE_ENTER_VALID_EMAIL_ADDRESS' => 'Please enter a valid email address',
	'JS_CONTAINS_ILLEGAL_CHARACTERS' => 'contains illegal characters' ,
	'JS_PHONE_NUMBER_LENGTH_EXCEEDED' => 'phone number length exceeded limit',
	'JS_ACCEPT_POSITIVE_NUMBER'    => 'accepts only positive values',
	'JS_VALUE_SHOULD_BE_GREATER_THAN_ZERO' => 'value should be greater than zero',
	'JS_NUMBER_SHOULD_BE_LESS_THAN_32' => 'Number should be less than 32', // TODO: Review
	'JS_PLEASE_ENTER_VALID_DATE'   => 'Please Enter Valid Date'     , // TODO: Review
	'JS_PLEASE_ENTER_VALID_TIME'   => 'Please Enter Valid Time'     , // TODO: Review
	'JS_INVALID_PAGE_NUMBER'       => 'Invalid Page Number'         , // TODO: Review
	'INVALID_NUMBER_OF'            => 'Invalid number'              ,
	'INVALID_NUMBER'               => 'Invalid number'              , // TODO: Review
	'JS_LBL_ARE_YOU_SURE_YOU_WANT_TO_DELETE' => 'Are you sure that you want to delete?',
	'OVERWRITE_EXISTING_MSG1'      => 'Overwrite the existing address with the selected address?',
	'OVERWRITE_EXISTING_MSG2'      => 'Address Details'             ,
	'SINGLE_Accounts'              => 'Organisation'                ,
	'SINGLE_Contacts'              => 'Contact'                     ,
	'LBL_DELETE_CONFIRMATION'      => 'Are you sure you want to Delete?',
	'LBL_MASS_DELETE_CONFIRMATION' => 'Are you sure you want to delete the selected Records?',
	'JS_LBL_SAVE'                  => 'Save'                        ,
	'JS_LBL_CANCEL'                => 'Cancel'                      ,
	'SHOULD_BE_LESS_THAN_TODAY'    => 'Must occur before today'     ,
	'JS_PLEASE_SELECT_ATLEAST_ONE_OPTION' => 'Please select atleast one option',
	'JS_SELECT_MODULE'             => 'Please select any module to search'        ,
	'JS_PLEASE_SELECT_ATLEAST_ONE_MANDATORY_FIELD' => 'Please select atleast one Mandatory Field',
	'JS_PLEASE_ENTER_INTEGER_VALUE' => 'Please enter integer value'  ,
	'JS_PLEASE_ENTER_DECIMAL_VALUE' => 'Please enter decimal value'  ,
	'JS_PLEASE_ENTER_POSITIVE_DECIMAL_VALUE' => 'Please enter positive decimal value',
	'JS_SHOULD_BE_LESS_THAN_CURRENT_DATE' => 'should be less than Current Date',
	'JS_SHOULD_BE_GREATER_THAN_CURRENT_DATE' => 'should be greater than current date',
	'JS_SHOULD_BE_GREATER_THAN_OR_EQUAL_TO' => 'should be greater than or equal to',
	'JS_SHOULD_BE_LESS_THAN_OR_EQUAL_TO' => 'should be less than or equal to', // TODO: Review
    'JS_CURRENT_DATE' => 'Current Date',
	'JS_PERCENTAGE_VALUE_SHOULD_BE_LESS_THAN_100' => 'Percentage value should be less than 100', // TODO: Review
	'JS_ACCEPT_ONLY_NUMBER'        => 'Accepts only numbers'        , // TODO: Review
	'JS_THIS_FILE_HAS_ALREADY_BEEN_SELECTED' => 'This File has already been selected', // TODO: Review
	'JS_MAX_FILE_UPLOAD_EXCEEDS'   => 'max file Upload exceeds'     , // TODO: Review
	'JS_THIS_DOCUMENT_HAS_ALREADY_BEEN_SELECTED' => 'This Document has already been attached', // TODO: Review
	'JS_FAILED_TO_SAVE'            => 'Failed to save changes on server',
	'JS_IMPORT_FILE_CAN_NOT_BE_EMPTY' => 'Import File cannot be Empty' ,
	'JS_PLEASE_SELECT_ONE_FIELD_FOR_MERGE' => 'Select at least one field for merge criteria',
	'JS_MAP_NAME_CAN_NOT_BE_EMPTY' => 'Map Name cannot be empty'    ,
	'JS_MAP_NAME_ALREADY_EXISTS'   => 'Map Name already exists'     ,
	'JS_SELECT_FILE_EXTENSION'     => 'Please select a file with the following extension:',
	'JS_UPLOADED_FILE_SIZE_SHOULD_BE_LESS_THAN' => 'Upload file size should be less than', // TODO: Review
	'JS_UPLOADED_FILE_SIZE_EXCEEDS' => 'Uploaded file size exceeds'  , // TODO: Review
	'JS_PLEASE_SPLIT_FILE_AND_IMPORT_AGAIN' => 'Please split the file into smaller files and import again.', // TODO: Review
	'JS_FIELD_MAPPED_MORE_THAN_ONCE' => 'Field mapped more than once' ,
	'JS_MAP_MANDATORY_FIELDS'      => 'Please map mandatory fields' ,
	'JS_PLEASE_ENTER_SOME_VALUE'   => 'Please enter some value to search',
	'JS_YOU_CAN_SELECT_ONLY'       => 'You can select only'         ,
	'JS_ITEMS'                     => 'items'                       ,
	'JS_LBL_PERMISSION'            => 'Permissions'                 ,
	'JS_CHECK_FILE_INTEGRITY'      => 'Check File Integrity'        ,
	'JS_DUPLICATE_RECORD'          => 'Duplicate Record'            ,
	'JS_IS_ENABLED'                => 'is enabled'                  ,
	'JS_IS_DISABLED'               => 'is disabled'                 ,
	'JS_PLEASE_ENTER_SOME_TEXT_FOR_COMMENT' => 'Please enter some text for comment',
	'JS_LBL_COMMENT_VALUE_CANT_BE_EMPTY' => 'Comment value cannot be empty',
	'JS_REQUIRED_FIELD'            => '* This field is required'    ,
	'JS_CAN_NOT_REMOVE_DEFAULT_WIDGET' => 'Cannot remove Default Widget',
	'JS_NO_CREATE_OR_NOT_QUICK_CREATE_ENABLED' => 'No create permissions or not enabled for quick create',
	'LBL_IMAGE_DELETED_SUCCESSFULLY' => 'Image Deleted Successfully'  ,
	'LBL_IMAGE_NOT_DELETED'        => 'Image Not Deleted'           ,
	'LBL_YES'                      => 'Yes'                         ,
	'LBL_NO'                       => 'No'                          ,
	'AM'                           => 'AM'                          ,
	'PM'                           => 'PM'                          ,
	'JS_ERROR'                     => 'Error'                       , // TODO: Review
	'JS_INFORMATION'               => 'Information'                 , // TODO: Review
	'JS_DO_NOT_HAVE_AN_EMAIL_ID'   => 'does not have an email address', // TODO: Review
	'NONE_OF_THE_FIELD_VALUES_ARE_CHANGED_IN_MASS_EDIT' => 'None of the field values are changed in Mass Edit', // TODO: Review
	'JS_PLEASE_SELECT_AN_ACCOUNT_TO_COPY_ADDRESS' => 'Please select an Organisation to copy address', // TODO: Review
	'JS_PLEASE_SELECT_AN_CONTACT_TO_COPY_ADDRESS' => 'Please select a Contact to copy address', // TODO: Review
	'JS_SELECTED_ACCOUNT_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Organisation does not contain address to copy', // TODO: Review
	'JS_SELECTED_CONTACT_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Contact does not contain address to copy', // TODO: Review
	'JS_PLEASE_ENTER_PRIMARY_EMAIL_VALUE_TO_ENABLE_PORTAL_USER' => 'Please enter Primary email address to enable portal user', // TODO: Review
	'JS_PRIMARY_EMAIL_FIELD_DOES_NOT_EXISTS' => 'Primary email field does not exist to enable portal user', // TODO: Review
	'JS_PLEASE_ENTER_A_TAG'        => 'Please enter a tag'          , // TODO: Review
	'JS_TAG_NAME_ALREADY_EXIST'    => 'Tag name already exist'      , // TODO: Review
	'JS_MAX_TAG_LENGTH_EXCEEDS'    => 'Tag length exceeds max size' , // TODO: Review
	'JS_NO_VIEW_PERMISSION_AFTER_SAVE' => 'You will not have permissions to view this record after save. Would you like to continue?', // TODO: Review
	'JS_NO_RECORDS_RELATED_TO_THIS_FILTER' => 'No Records Related to this Filter', // TODO: Review
	'JS_START_DATE_TIME'           => 'Start Date & Time'           , // TODO: Review
	'JS_END_DATE_TIME'             => 'End Date & Time'             , // TODO: Review
	'JS_POSTPONE'                  => 'Postpone'                    , // TODO: Review
	'JS_MESSAGE'                   => 'Message'                     , // TODO: Review
	'JS_MASS_EDIT_LIMIT'	       => 'Mass Edit operation can be done on 500 or less records at a time',
	'JS_SUCCESSFULLY_PINNED'       => 'Shortcut added successfully' , // TODO: Review
	'JS_SUCCESSFULLY_UNPINNED'     => 'Shortcut removed successfully', // TODO: Review
	'JS_SHORTCUT_ALREADY_ADDED'    => 'This shortcut is already added', // TODO: Review
	'JS_MODULE_ENABLED'            => 'Module Enabled'              , // TODO: Review
	'JS_MODULE_DISABLED'           => 'Module Disabled'             , // TODO: Review
	'JS_VALUE_SHOULD_NOT_BE_LESS_THAN' => 'Frequency of any cron job configured should not be less than', // TODO: Review
	'JS_MINUTES'                   => 'mins'                        , // TODO: Review
	'JS_ITEM_RENAMED_SUCCESSFULLY' => 'Item Renamed Successfully'   , // TODO: Review
	'JS_ITEM_ADDED_SUCCESSFULLY'   => 'Item added Successfully'     , // TODO: Review
	'JS_NO_ITEM_SELECTED'          => 'No item Selected'            , // TODO: Review
	'JS_MORE_THAN_ONE_ITEM_SELECTED' => 'More than one Item selected' , // TODO: Review
	'JS_ITEMS_DELETED_SUCCESSFULLY' => 'Items Deleted Successfully'  , // TODO: Review
	'JS_DUPLICATE_ENTRIES_FOUND_FOR_THE_VALUE' => 'Duplicate entries found for the value', // TODO: Review

	//User Password
	'JS_PASSWORD_INCORRECT_OLD'=>'Incorrect old password specified. Re-enter password information.',
	'JS_PASSWORD_CHANGED_SUCCESSFULLY' => 'Password Changed Successfully.',
	'JS_REENTER_PASSWORDS'=>'Please re-enter passwords.  The "new password" and "confirm password" values do not match.',
	'JS_RECORDS_TRANSFERRED_SUCCESSFULLY' => 'Records ownership transferred successfully.',
	'JS_USER_EXISTS' => 'User Already Exists',//TODO Review
	'JS_REENTER_PASSWORDS' => 'Renter Passwords',//TODO Review
	'LBL_SIGN_IN_AS_USER'=>'Logging in as another user will terminate the current session. Are you sure want to continue?',

        //For Print Templates
        'JS_MAX_RECORDS_LIMIT' => 'Maximum records for selection is :',
        'JS_NONE' => 'None',
	'SINGLE_Vendors'               => 'Vendor',

	//Feedback on removing old version
	'JS_PLEASE_GIVE_YOUR_FEEDBACK' => 'Please Fill your Feedback',
    'JS_NO_EDIT_PERMISSION' => 'You don\'t have the permission to edit this event',

        //Google Synchronization
        'SYNC_REMOVED_SUCCESSFULLY' => 'Google synchronisation removed successfully.',
        'REMOVE_SYNCHRONIZATION_MESSAGE' => 'Clicking on this will remove existing Gmail authentication. It will not delete any records which are already synchronised.',
        'REMOVE_SYNCHRONIZATION' => 'Remove Synchronisation',
        'FIELD_MAPPING' => 'Field Mapping',
        'LBL_SYNC_BUTTON' => 'Synchronise Now',
        'LBL_SYNCRONIZING' => 'Synchronising....',
        'LBL_NOT_SYNCRONIZED' => 'You have not synchronised yet',
        'LBL_FIELD_MAPPING' => 'Field Mapping',

        'LBL_RESTORE_CONFIRMATION' => 'Records previously assigned to this user will not be restored. Are you sure you want to restore this user?',
        'LBL_DELETE_USER_PERMANENT_CONFIRMATION' => 'Once deleted this user cannot be restored back. Are you sure you want to delete this user permanently?',

        'LBL_LANGUAGE_LABEL_VALIDATION' => 'Label value cannot be empty. You must enter some value.',
    	'JS_CHANGES_WILL_BE_LOST' => 'Your Changes Will Be Lost!',
		'JS_RECORD_DELETED' => 'Record deleted',
    'JS_NO_DELETE_PERMISSION' => 'No delete permission',
    'JS_CONFIRM_MARK_AS_HELD' => 'Are you sure you want to mark Event/Todo as Held?',
    'JS_TODO_MARKED_AS_COMPLETED' => 'Todo marked as Completed',
    'JS_EVENT_MARKED_AS_HELD' => 'Event marked as Held',
    'JS_FUTURE_EVENT_CANNOT_BE_MARKED_AS_HELD' => 'Future event cannot be marked as Held',
    'JS_PERMISSION_DENIED' => 'Permission denied',
    'LBL_SMS_MAX_CHARACTERS_ALLOWED' => 'Maximum 160 characters are allowed for text message',
    'JS_VIEWNAME_ALERT' => 'Maximum 40 characters are allowed for filter name',

    'JS_EXCEEDS_MAX_UPLOAD_SIZE' => 'Exceeded maximum upload size',
    'JS_FUTURE_EVENT_CANNOT_BE_HELD' => 'Cannot Be Held For Future',
    'LBL_WARNING' => 'Warning',
    'DELETE_USER_PERMANENT_WARNING' => 'Deleting a user permanently will transfer all records including comments and history to new user.',
    'JS_CLOSE' => 'Close',
    'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
    // For Line Iteam Currency Symbol select while Import
    'JS_CURRENCY_TOOLTIP_CONTENT_TITLE' => 'Line Items Currency',
    'JS_CURRENCY_TOOLTIP_CONTENT_MESSAGE' => 'For importing Currency values in Line items, Vtiger will use this setting to identify the currency. Any currency values outside the line items tables, are assumed to be in User\'s preferred currency (selected in \'My Preferences\')',
	'LBL_CANT_SELECT_CONTACT_FROM_LEADS' => 'Cannot select related Contacts for Leads',
    'JS_FILE_NAME' => 'File Name',
    'JS_EXTERNAL_FILE_URL' => 'File Url',
    'JS_PLEASE_SELECT_A_FILE' => 'Please select a file',
    
     // SMSNotifier Phone Format Warning
    'JS_PHONEFORMAT_ERROR' => 'Please check the phone number is in internatonal E.164 format with \'+\' prefix and the country code  Ex +1 415 599 2671',
    
    // Leads and Potentials Mapping 
    'JS_NONE'                      => 'None'                        , // TODO: Review
	'JS_IS_ALREADY_BEEN_MAPPED'    => 'is already been mapped'      , // TODO: Review
	'JS_CANT_MAP'                  => 'Cant map'                    , // TODO: Review
	'JS_WITH'                      => 'with'                        , // TODO: Review
	'JS_MAPPING_DELETED_SUCCESSFULLY' => 'Mapping Deleted Successfully', // TODO: Review
	'JS_phone'                     => 'Phone'                       , // TODO: Review
	'JS_picklist'                  => 'Pick List'                   , // TODO: Review
	'JS_email'                     => 'Email'                       , // TODO: Review
	'JS_text'                      => 'String'                      , // TODO: Review
	'JS_currency'                  => 'Currency'                    , // TODO: Review
	'JS_multiSelectCombo'          => 'Multi-Select Combo Box'      , // TODO: Review
	'JS_time'                      => 'Time'                        , // TODO: Review
	'JS_textArea'                  => 'Text Area'                   , // TODO: Review
	'JS_url'                       => 'Url'                         , // TODO: Review
	'JS_string'                    => 'String'                      , // TODO: Review
	'JS_checkBox'                  => 'Check Box'                   , // TODO: Review
	'JS_date'                      => 'Date'                        , // TODO: Review
	'JS_decimal'                   => 'Decimal'                     , // TODO: Review
	'JS_percent'                   => 'Percent'                     , // TODO: Review
	'JS_skype'                     => 'Skype'                       , // TODO: Review
	'JS_None'                      => 'None'                        , // TODO: Review
	'JS_integer'                   => 'Integer'                     ,
    'JS_double'                    => 'Decimal'                     ,
    'JS_reference'                 => 'reference'                   ,
	'JS_image' => 'Image',

    // AutoFill Overwriting message
    'JS_OVERWRITE_AUTOFILL_MSG1'   => 'Would you like to overwrite existing',
    'JS_OVERWRITE_AUTOFILL_MSG2'   => 'with selected'               ,
    'JS_PRINT' => 'Print',
    'JS_SAVE_AS_IMAGE' => 'Save As Image',

     //Demo Data Module Translatios
    'JS_ADD_DEMO_DATA_CONFIRMATION'=> 'Are you sure you want to add demo records to all modules?',
    'JS_ADD_DEMO_DATA_INFO'=> 'Demo records can be deleted by clicking the "Clear Demo Data" button.',
    'JS_CLEAR_DEMO_DATA_CONFIRMATION'=> 'Are you sure you want to clear demo data in all modules?',
    'JS_CLEAR_DEMO_DATA_INFO'=> 'Demo records can be added by clicking the "Add Demo Data" button.',
    'JS_DEMO_DATA_GETTING_POPULATED'=> 'Demo Data is being added, please wait...',
    'JS_DEMO_DATA_GETTING_CLEARED'=> 'Demo data is being cleared, please wait...',
    'JS_DEMO_DATA_ADDED' => 'Demo data added to all modules.',
    'JS_DEMO_DATA_CLEARED' => 'Demo data cleared from all modules.',
    'JS_HOME_DASH_BOARD_CLEAR_INFO'=>'Note: You can re-enable demo data from',
    'JS_SETTINGS_PATH'=>'Settings > Other Settings > Configuration Editor.',
    'JS_DIRECTORY_IS_EMPTY' => 'Directory is empty',
	'JS_PLEASE_SELECT_AN_RELATED_TO_COPY_ADDRESS' => 'Please select a Lead / Contact to copy address',
	'SINGLE_Leads' => 'Lead',
	'JS_SELECTED_LEAD_DOES_NOT_HAVE_AN_ADDRESS' => 'Selected Lead does not contain address to copy',
    'JS_INVALID_EMAILS' => 'Invalid Emails',
    'JS_INTERNAL_COMMENT' => 'Internal Comment',
    'JS_INTERNAL_COMMENT_INFO' => 'The comment will only be seen by CRM users, if the internal comment checkbox is enabled. To notify customers (through configurable workflows or customer portal) leave this checkbox disabled',
    'JS_NO_LINE_ITEM' =>'Line items cannot be empty.',

	//more currencies
	'JS_BASE_CURRENCY_CHANGED_TO_DISABLE_CURRENCY' => 'Base Currency has to be changed to disable ',
	'JS_INTERNAL_COMMENT' => 'Internal Comment',
    'JS_INTERNAL_COMMENT_INFO' => 'The comment will only be seen by CRM users, if the internal comment checkbox is enabled. To notify customers (through configurable workflows or customer portal) leave this checkbox disabled',

	'JS_NO_TAXES_EXISTS' => 'No taxes exist',
	'JS_CONFIRM_TAXES_AND_CHARGES_REPLACE' => 'Do you want to update tax & charge values corresponding to selected region?',
    'JS_PRINTTEMPLATEMODULE_DISABLED' => 'PrintTemplates module is disabled. Cannot perform the operation',
    'JS_SENT_FOR_SIGNATURE' => 'Sent for signature',
    'JS_FAILED_TO_SEND_FOR_SIGNATURE' => 'Failed to send for signing',
    // Cron
    'JS_NONE_OF_THE_VALUES_ARE_CHANGED' => 'None of the values are changed',

	'JS_SUITABLE_VTIGER_FIELD_NOT_AVAILABLE_FOR_MAPPING' => 'Suitable vtiger field not available for mapping',
    'JS_SAVED_SUCCESSFULLY' => 'Settings saved successfully',
    'phone' => 'Phone',
    'email' => 'Email',
    'url' => 'Url',
    'home' => 'Home',
    'work' => 'Work',
    'custom' => 'Custom',
    'mobile' => 'Mobile',
    'main' => 'Main',
    'work_fax' => 'Fax',
    'home_fax' => 'Home Fax',
    'pager' => 'Pager',
    'profile' => 'Profile',
    'blog' => 'Blog',
    'home-page' => 'Homepage',
    'address' => 'Address',
    'JS_REMOVE_SYNC_CONFIRMATION' => 'Remove synchronisation will only remove existing authentication, it will not delete synchronised records. If you synchronise with same Google account again, duplicate records will be created. Are you sure you want to remove synchronisation?',
    
    // Social Module Strings
    'JS_PLEASE_WAIT' => 'Please Wait...',
    'JS_SOCIAL_FIELD_ERROR' => 'field is required',
    // Twitter Specific
    'JS_ADD_FAVOURITE_SUCCESS_MSG' => 'Added Tweet to favourite list successfully',
    'JS_UNDO_FAVOURITE_SUCCESS_MSG' => 'Removed Tweet from favourite list successfully',
    'JS_UNDO_RETWEET_SUCCESS_MSG' => 'UndoRetweet successfully',
    'JS_STATUS_UPDATE_SUCCESS_MSG' => 'Updated successfully',
    'JS_TWEET_DELETE_MSG' => 'Status Deleted successfully',
    'JS_INVALID_TWITTER_HANDLER_NAME' => 'Invalid Twitter Handler Name',
    'JS_RELATION_ADDED_SUCESSFULLY' => 'Relation Added Successfully',
    'JS_FAILED_TO_ADD_RELATION' => 'Failed To Add Relation',
    'JS_SOCIAL_POST_DELETE_CONFIRMATION' => 'Are you sure you want to delete?',
    'JS_EVENT_OR_TODO_ADDED_SUCCESS_MSG' => 'Event/Todo added sucessfully',
    'JS_LEAD_ADDED_SUCCESS_MSG' => 'Lead added successfully',
    'JS_OPPORTUNITY_ADDED_SUCESS_MSG' => 'Opportunity added successfully',
    'JS_TICKET_ADDED_SUCESS_MSG' => 'Ticket added successfully',
    'JS_SELECT_OPTION' => 'Select an Option',

    //Office365
    'LBL_REMOVE_SYNC_CONFIRMATION' => 'Removes Authorization for Contacts, Calendars and Emails. Are you sure you want to remove sync?',
    'OFFICE365_SYNC_REMOVED_SUCCESSFULLY' => 'Office365 sync removed successfully',
    'OFFICE365_REMOVE_SYNCHRONIZATION_MESSAGE' => 'Clicking on this will remove existing Office365 authentication. It will not delete any records which are already synchronised. It will not unregister the Vtiger app from you office365 account, to unregister visit https://myapps.microsoft.com/',
    
    'JS_LOADING_COMMENTS' => 'Fetching Comments ...',
    'JS_PASSWORD_MISMATCH_ERROR' => 'Please re-enter passwords.  The "new password" and "confirm password" values do not match.',
    'JS_COMMA_NOT_ALLOWED_USERS' => 'Special characters like ,"<> are not allowed in First Name and Last Name.',
    'Payment Failure!' => 'Payment Failure!',
    'We could not process the payment for your last invoice. Please update payment info to continue using the service without disruption.' => 'We could not process the payment for your last invoice. Please update payment info to continue using the service without disruption.',
    'For assistance, please send email to' => 'For assistance, please send email to',
    'JS_MAX_ALLOWED_CHARACTERS' => 'Maximum allowed characters is',

	'JS_DEFAULT_ENABLED' => 'Default enabled',
	'JS_DEFAULT_DISABLED' => 'Default disabled',

  'JS_PLEASE_ENTER_VALID_VALUE' => 'Please enter a valid value',
  'JS_PLEASE_ENTER_VALID_TAG_NAME' => 'Please enter valid tag name',
  'JS_TAG_SAVED_SUCCESSFULLY' => 'Tag Saved Successfully',
  'JS_SUBJECT_VALUE_CANT_BE_EMPTY' => 'Subject value cannot be empty',
  'JS_PERCENTAGE_SHOULD_BE_LESS_THAN_100' => 'Percentage should be less than 100',
  'LBL_DELETE_USER_CONFIRMATION' => 'When a user is deleted, the user will be marked as "Inactive" and no new records can be assigned to the user and the user will not be able to login. Billing will stop for this user. If you need to reactivate a deleted user, you will need to send email to support@vtiger.com. Are you sure you want to delete?',
  'JS_DUPLICATE_CREATION_CONFIRMATION' => 'Organisation Name already Exists. Do you want to create a duplicate record?',
  'JS_SELECT_RECORDS_TO_MERGE_FROM_SAME_GROUP' => 'You have to select the records in the same groups for merging',
  'JS_SELECT_ATLEAST_TWO_RECORD_FOR_MERGING' => 'Select at least two records for merging',
  'JS_ALLOWED_TO_SELECT_MAX_OF_THREE_RECORDS' => 'You are allowed to select a maximum of three records',
  'JS_ARE_YOU_SURE_TO_DELETE_WIDGET' => 'Are you sure to delete widget',
  'JS_ARE_YOU_SURE_TO_DELETE_DASHBOARDTAB' => 'Are you sure to delete tab',
  'JS_TABS_LIMIT_EXCEEDED' => 'Sorry! Can\'t add more than 10 tabs',
  'JS_TOTAL_RECORDS' => 'Total records',
  'JS_PAGE_NOT_EXIST' => 'Page not exist',
  'JS_YOU_ARE_IN_PAGE_NUMBER' => 'You are in page number',
  'JS_PLEASE_ENABLE_BASE_CURRENCY_FOR_PRODUCT' => 'Please enable base currency for product',
  'JS_PLEASE_SELECT_BASE_CURRENCY_FOR_PRODUCT' => 'Please select base currency for product',
  'JS_RECORDS_ARE_GETTING_DELETED' => 'Records are getting deleted',
  'JS_RECORD_GETTING_DELETED' => 'Record getting deleted',
  'JS_NO_RESULTS_FOUND' => 'No Results Found',
  'JS_RECORDS TRANSFERRED SUCCESSFULLY' => 'Records ownership has been tranferred successfully',
  'LBL_SEARCHING' => 'Searching in ',
  'JS_USER_DELETED_SUCCESSFULLY' => 'User deleted successfully.',
  'JS_PBX_CALL_FROM' => 'Call From',
  'JS_PBX_INCOMING_CALL' => 'Incoming Call',
  'JS_PBX_OUTGOING_SUCCESS' => 'Pick up the extension receiver to dial the number',
  'JS_PBX_OUTGOING_FAILURE' => 'Call Failed',
  'JS_PBX_FILL_ALL_FIELDS' => 'Please fill all the fields',
  'JS_PBX_CAMPAIGN_NAME' => 'Campaign Name',
  'JS_PBX_CAMPAIGN_NUMBER' => 'Campaign Number',
  'JS_MIN_SEARCH_KEY_LENGTH' => 'Search Key should have aleast 3 characters',
  'JS_NO_MATCH' => 'No Matching Records Found',
  'JS_PBX_OUTGOING_CALL' => 'Outgoing Call',
  'JS_PBX_CALL_TO' => 'Call To',
  'JS_REQUIRED' => 'Required',
  'JS_PHONE_NUMBER' => 'Phone Number',
  'JS_NO_CREATE_PERMISSION' => 'Call need to be answered before creating record',
  'HelpDesk' => 'Tickets',
  'Potentials' => 'Opportunities',
  'JS_TRY_LATER' => 'Please try later!',
  'JS_CANCEL_SUBSCRIPTION_CONFIRMATION' => 'Are you sure you want to cancel the SUBSCRIPTION?',
  'JS_PLAN_CHANGED_SUCCESSFULLY' => 'New Plan Activated Successfully.',
  'JS_SUBSCRIPTION_CANCELLED_SUCCESSFULLY' => 'Subscription cancelled successfully.',
  'JS_REACTIVATED_SUCCESSFULLY' => 'Vtiger Subscription reactivated successfully',
  'JS_PAYMENTMETHOD_ADDED_SUCCESSFULLY' => 'Thanks for subscribing. Your payment method added successfully',
  'JS_EXCLUSIVE_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Exclusive plan monthly subscription fee ($12 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Exclusive Plan Monthly.',
  'JS_ULTIMATE_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Ultimate plan monthly subscription fee ($36 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Ultimate Plan Monthly.',
  'JS_SALESPREMIUM_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Sales Premium plan monthly subscription fee ($24 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Sales Premium Plan Monthly.',
  'JS_SUPPORT_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Support plan monthly subscription fee ($12 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Support Plan Monthly.',
  'JS_SALES_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Sales plan monthly subscription fee ($12 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Sales Plan Monthly.',
  'JS_CONTACT_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Contact Management plan monthly subscription fee ($9 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Contact Management Plan Monthly.',
  'JS_EXCLUSIVE_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Exclusive plan annual subscription fee ($132 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Exclusive Plan Annual.',
  'JS_ULTIMATE_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Ultimate plan annual subscription fee ($360 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Ultimate Plan Annual.',
  'JS_SALESPREMIUM_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Sales Premium plan annual subscription fee ($240 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Sales Premium Plan Annual.',
  'JS_SUPPORT_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Support plan annual subscription fee ($120 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Support Plan Annual.',
  'JS_SALES_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Sales plan annual subscription fee ($120 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Sales Plan Annual.',
  'JS_CONTACT_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Contact Management plan monthly subscription fee ($99 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Contact Management Plan Annual.',
  'JS_LBL_GETTING_RECIPIENT_PREFS' => 'Getting recipient preferences..',
  'JS_LBL_SAVING_PREFERENCES' => 'Saving preferences..',
  'JS_CASE_ADDED_SUCESS_MSG' => 'Case added successfully',
  'JS_ENTERED_CURRENT_USERNAME_MSG' => 'You entered the current username. Please enter new username.',
  'JS_LOADING_PLEASE_WAIT' => 'Loading... Please wait..',
  'JS_SAVING_PLEASE_WAIT' => 'Saving.. Please wait..',
  'JS_DUPLICATE_EMAILS_PLEASE_CHECK' => 'Duplicate email addresses. Please check',
  'JS_ALERT' => 'Alert',
  'JS_SUCCESS' => 'Success',
  'JS_REMOVE_MASS_TAG_WARNING' => 'Are you sure you want to remove %s tag for selected records',
  'JS_VIEW_ALREADY_EXISTS' => 'View already exists',
  'JS_PLEASE_ENTER_NUMBER_IN_RANGE' => 'Please enter value in the range',
  'JS_UPLOAD' => 'Upload',
  'JS_TODO_ADDED_SUCCESS_MSG' => 'Task added successfully',
  'JS_EVENT_ADDED_SUCCESS_MSG' => 'Event added successfully',
  'JS_ACTIVE' => 'Active',
  'JS_SNOOZED' => 'Snoozed',
  'JS_INVALID_URL' => 'Invalid URL',
  'JS_ARE_YOU_SURE_YOU_WANT_TO_DELETE' => 'Are you sure you want to delete?',
  'JS_TAB_LABEL_EXCEEDS_CHARS' => 'Tab label length should be less than %s characters',
  'JS_STARRED' => 'Starred',
  'JS_NOT_STARRED' => 'Not Starred',
  'JS_NO_TAG_EXISTS' => 'No Tag Exists',
  'JS_HELP_AND_SUPPORT' => 'Help & Support',
  'JS_WHAT_DO_YOU_NEED_HELP_WITH' => 'What do you need help with?',
  'JS_SUBMIT' => 'Submit',
  'JS_ADD_MAX_15_ITEMS' => 'You can only add 15 items',
  'SINGLE_SLA' => 'SLA',
  'JS_EDIT_FIELDS' => '%s Fields & Layout',
  'JS_MORE_VTIGER' => 'There are more records to be synchronised in vtiger',
  'JS_MORE_GOOGLE' => 'There are more records to be synchronised in Google',
  'JS_MORE_OFFICE365' => 'There are more records to be synchronised in Office365',
  'JS_TOKEN_EXPIRED' => 'Office365 Authentication has expired. Click on Sign in with Office365 button to re-authorise.',
  'JS_WISH_TO_PROCEED' => 'Are you sure you want to proceed?',
  'JS_SWITCH_TO_OLD_LOOK_CONFIRMATION_MESSAGE' => 'Some features, including notifications, picklist colors, follow record, are not available in old version. You may switch back to new version by choosing new version from top right menu.',
  'JS_PROCEED_OLD_VERSION' => 'Proceed to old version',
  'JS_STAY_WITH_NEW_VERSION' => 'Stay with new version',
  'JS_AGO' => 'ago',
  'JS_FROM_NOW' => 'from now',
  'JS_LESSTHAN_A_MINUTE' => 'less than a minute',
  'JS_A_MINUTE' => 'a minute',
  'JS_AN_HOUR' => 'an hour',
  'JS_HOURS' => 'hours',
  'JS_A_DAY' => 'a day',
  'JS_DAYS' => 'days',
  'JS_A_MONTH' => 'a month',
  'JS_MONTHS' => 'months',
  'JS_A_YEAR' => 'a year',
  'JS_YEARS' => 'years',
  'JS_TODAY' => 'today',
  'JS_TOMORROW' => 'tomorrow',
  'JS_YESTERDAY' => 'yesterday',
  'JS_CREATE_TASK' => 'Create Task',


  'JS_SUPPORTPREMIUM_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'Support Premium plan monthly subscription fee ($24 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Support Premium Plan Monthly.',
  'JS_SUPPORTPREMIUM_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'Support Premium plan annual subscription fee ($240 per user. Your account will be charged the difference in the price for the remaining portion of the current billing period. Please confirm if you wish to proceed to the Support Premium Plan Annual.',


  'JS_MENTION_ATLEAST_ONE_USER' => 'Mention atleast one user',
  'JS_LOADING' => 'Loading...',
	'JS_UPLOAD_SUCCESSFUL' => 'File Uploaded Successfuly',
    'JS_UPLOAD_FAILED' => 'File Upload Failed',

	'JS_DUPLICATES_DETECTED' => 'Duplicate(s) detected!',
	'JS_PASSWORD_MISMATCH_ERROR' => 'Please re-enter passwords. The "new password" and "confirm password" values do not match.',
	'JS_LIST_DELETE_CONFIRMATION' => 'Are you sure you want to delete?',
	'JS_WIDGET_RESIZING_WAIT_MSG' => 'Widget contents will load after resizing.',
);
